Test Report

# Summary

Started | 2025-06-02 16:28:18
Ended | 2025-06-02 16:37:19
Duration | 0:09:01.469988
Total run time | 0:08:46.058497

100 passed 5 skipped

# Warnings

## Warnings 190

- DeprecationWarning Please import `gaussian_filter1d` from the `scipy.ndimage` namespace; the `scipy.ndimage.filters` namespace is deprecated and will be removed in SciPy 2.0.0.
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/isofit/utils/instrument_model.py:25
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:98
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:102
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:73
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:67
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:115
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:107
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- DeprecationWarning 'pkgutil.get_loader' is deprecated and slated for removal in Python 3.14; use importlib.util.find_spec() instead
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/acwater/polymer_enmap.py:53
- DeprecationWarning 'pkgutil.get_loader' is deprecated and slated for removal in Python 3.14; use importlib.util.find_spec() instead
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/acwater/level1_enmap.py:67
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Automatic nodata value detection returned the value 0.0 for GeoArray 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER' but this seems to be unreliable (occurs in only 2 image corners). To avoid automatic detection, just pass the correct nodata value.
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/geoarray/baseclasses.py:806
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=172) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66

# Tests

## tests/test_cli_parser.py 7 0:00:00.731796

### PASSED Test_CLIParser::test_json_opts 0:00:00.192844

Started | 2025-06-02 16:28:30
Ended | 2025-06-02 16:28:30
Duration | 0:00:00.192844
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_output_nodata_value 0:00:00.121354

Started | 2025-06-02 16:28:30
Ended | 2025-06-02 16:28:30
Duration | 0:00:00.121354
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_acceptance 0:00:00.080018

Started | 2025-06-02 16:28:30
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.080018
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_boolean 0:00:00.129137

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.129137
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_list 0:00:00.046354

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.046354
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_tgtepsg 0:00:00.081111

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.081111
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_tgtprj 0:00:00.080979

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.080979
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_config.py 13 0:00:00.380764

### PASSED Test_get_options::test_target_is_file_no_validation 0:00:00.008397

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.008397
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_get_options::test_target_is_file_validation 0:00:00.017157

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.017157
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_invalid_filepath 0:00:00.035990

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.035990
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_file 0:00:00.043888

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.043888
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_param_acceptance 0:00:00.037114

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.037114
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_allfine 0:00:00.037489

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.037489
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_badcomment 0:00:00.017286

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.017286
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_nojson 0:00:00.017495

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.017495
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_schema_violation 0:00:00.026760

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.026760
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_undecodable_val 0:00:00.017029

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.017029
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_plain_args 0:00:00.036147

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.036147
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_to_dict_validity 0:00:00.048489

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.048489
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_to_jsonable_dict 0:00:00.037521

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:31
Duration | 0:00:00.037521
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_controller.py 5 0:03:01.562713

### PASSED Test_EnPT_Controller::test_run_all_processors 0:00:09.835392

Started | 2025-06-02 16:28:31
Ended | 2025-06-02 16:28:41
Duration | 0:00:09.835392
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': True,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': True,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': 50,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/dem_map_geo.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/AlpineTest1_CWV2_SM0.zip',
                      'path_l1b_enmap_image_gapfill': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/AlpineTest2_CWV2_SM0.zip',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpvfv9qcsj'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': False,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'land',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spatial',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': False},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/02 16:28:32:   Reading metadata for VNIR detector...
    2025/06/02 16:28:32:   Calculating solar irradiance...
    2025/06/02 16:28:32:   Reading metadata for SWIR detector...
    2025/06/02 16:28:32:   Calculating solar irradiance...
    2025/06/02 16:28:32:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:28:33:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:28:33:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:28:33:   Reading metadata for VNIR detector...
    2025/06/02 16:28:33:   Calculating solar irradiance...
    2025/06/02 16:28:33:   Reading metadata for SWIR detector...
    2025/06/02 16:28:33:   Calculating solar irradiance...
    2025/06/02 16:28:33:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:28:33:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:28:33:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:28:33:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:28:33:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:28:33:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:28:33:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:28:34:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:28:35:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:28:35:   Skipping atmospheric correction as configured and computing top-of-atmosphere reflectance instead.
    2025/06/02 16:28:35:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/06/02 16:28:35:   Converting TOA radiance to TOA reflectance for SWIR detector...
    2025/06/02 16:28:35:   Starting orthorectification...
    2025/06/02 16:28:35:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32632): (627300.0, 5257740.0, 656040.0, 5266620.0)
    2025/06/02 16:28:35:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:28:36:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:28:38:   Merging VNIR and SWIR data...
    2025/06/02 16:28:38:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 16:28:38:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 16:28:39:   Generating L2A metadata...
    2025/06/02 16:28:41:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (296, 958, 209) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.TIF.
    Writing GeoArray of size (296, 958) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (296, 958, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (296, 958, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:28:41:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_header.xml
    2025/06/02 16:28:41:   L2A product successfully written!
    2025/06/02 16:28:41:   Total runtime of the processing chain: 0:00:09.769070

##### Captured stderr call

    2025/06/02 16:28:33:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 16:28:33:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 16:28:33:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 16:28:33:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 16:28:33:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 16:28:41:   The 'mask_landwater' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:28:41:   The 'mask_cloudshadow' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:28:41:   The 'mask_haze' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:28:41:   The 'mask_snow' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:28:41:   The 'mask_cirrus' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:28:41:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/02 16:28:41:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:28:41:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:28:41:   No XML metadata conversion implemented for datasets different to the DLR format.Metadata XML file will be empty.

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata::test_run_all_processors 0:00:54.918909

Started | 2025-06-02 16:28:41
Ended | 2025-06-02 16:29:36
Duration | 0:00:54.918909
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 24,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': 50,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-799.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmp3k2vd52v'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'land',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spatial',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': False},
                    'geometry': {'enable_absolute_coreg': True,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/T30TXQ_20170218T110111_B05__sub.tif'},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/02 16:28:42:   Reading metadata for VNIR detector...
    2025/06/02 16:28:42:   Calculating solar irradiance...
    2025/06/02 16:28:42:   Reading metadata for SWIR detector...
    2025/06/02 16:28:42:   Calculating solar irradiance...
    2025/06/02 16:28:42:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:28:43:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:28:43:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:28:43:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:28:44:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:28:44:   Computing VNIR geolayer...
    2025/06/02 16:28:44:   Computing SWIR geolayer...
    2025/06/02 16:28:44:   Temporarily transforming EnMAP band 40 to map geometry for co-registration.
    2025/06/02 16:28:45:   Temporarily transforming EnMAP water mask to map geometry for co-registration.
    2025/06/02 16:28:45:   Preparing reference image for co-registration.
    2025/06/02 16:28:45:   Computing tie points between the EnMAP image and the given spatial reference image.
    Calculating footprint polygon and actual data corner coordinates for reference image...
    Bounding box of calculated footprint for reference image:
    	(637005.0, 4940640.0, 666300.0, 4949895.0)
    Bounding box of calculated footprint for image to be shifted:
    	(637009.9236523756, 4940648.633479693, 666298.6703669054, 4949893.375184522)
    Matching window position (X,Y): 651655.4222751356/4945271.096554121
    Target window size (256, 256) not possible due to too small overlap area or window position too close to an image edge. New matching window size: (164, 164).
    Initializing tie points grid...
    With respect to the provided bad data mask(s) 81 points of initially 242 have been excluded.
    Calculating tie point grid (161 points) using 24 CPU cores...
    Found 131 matches.
    Performing validity checks...
    41 tie points flagged by level 1 filtering (reliability).
    63 tie points flagged by level 2 filtering (SSIM).
    4 tie points flagged by level 3 filtering (RANSAC)
    47 valid tie points remain after filtering.
    2025/06/02 16:28:56:   Generating misregistration array.
    interpolation runtime: 0.19s
    interpolation runtime: 0.16s
    2025/06/02 16:28:56:   Transforming spatial optimization results back to sensor geometry.
    2025/06/02 16:28:57:   Applying results of spatial optimization to geolayer.
    2025/06/02 16:28:57:   Pre-processing DEM for VNIR...
    2025/06/02 16:28:57:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/06/02 16:28:57:   Pre-processing DEM for SWIR...
    2025/06/02 16:28:57:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/06/02 16:28:57:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/06/02 16:28:58:   Starting atmospheric correction for VNIR and SWIR detector in 'land' mode. Source radiometric unit code is 'TOARad'.
    2025/06/02 16:28:58:   Running atmospheric correction in 'land' mode, i.e., SICOR is applied to ALL surfaces. Uncertainty is expected for water surfaces because SICOR is designed for land only.
    2025/06/02 16:28:58:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 24,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': False,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/06/02 16:28:58:   Setting up forward operator...
    2025/06/02 16:28:58:   SICOR is applied to land AND water pixels.
    2025/06/02 16:28:58:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/06/02 16:28:59:   Getting observation metadata...
    2025/06/02 16:28:59:   Checking if observation metadata values are within LUT value ranges...
    2025/06/02 16:28:59:   Loading solar irradiance model...
    2025/06/02 16:28:59:   Loading RT LUT...
    2025/06/02 16:28:59:   LUT file was properly downloaded and is available for AC!
    2025/06/02 16:29:00:   Converting LUT to Fontenla solar model...
    2025/06/02 16:29:00:   Resampling LUT to EnMAP wavelengths...
    2025/06/02 16:29:19:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/06/02 16:29:19:   Calculating absorption coefficients of liquid water and ice...
    2025/06/02 16:29:20:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/06/02 16:29:21:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/06/02 16:29:21:   Performing first guess liquid water retrieval based on the NDWI...
    2025/06/02 16:29:21:   Performing first guess ice retrieval based on the NDSI...
    2025/06/02 16:29:21:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/06/02 16:29:21:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/06/02 16:29:22:   Preparing segmented SWIR L1B data cube...
    2025/06/02 16:29:22:   Performing 3 phases of water retrieval...
    2025/06/02 16:29:22:   Setting up multiprocessing...
    2025/06/02 16:29:22:   Multiprocessing on 24 cpu's
    2025/06/02 16:29:22:   Preparing optimal estimation input...
    2025/06/02 16:29:22:   Optimization...
    2025/06/02 16:29:25:   Done!
    2025/06/02 16:29:25:   Runtime: 2.22 s
    2025/06/02 16:29:25:   Smoothing segmented CWV retrieval map...
    2025/06/02 16:29:25:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/06/02 16:29:25:   Starting surface reflectance retrieval...
    2025/06/02 16:29:25:   Calculating surface reflectance for vnir detector...
    2025/06/02 16:29:28:   Calculating surface reflectance for swir detector...
    2025/06/02 16:29:30:   Smoothing segmented liquid water and ice maps...
    2025/06/02 16:29:31:   SICOR atmospheric correction for EnMAP in land mode successfully finished!
    2025/06/02 16:29:31:   Joining results of atmospheric correction.
    2025/06/02 16:29:31:   Starting orthorectification...
    2025/06/02 16:29:31:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636960.0, 4940670.0, 666090.0, 4949310.0)
    2025/06/02 16:29:31:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:29:32:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:29:33:   Merging VNIR and SWIR data...
    2025/06/02 16:29:33:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 16:29:33:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 16:29:33:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 16:29:33:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 16:29:34:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 16:29:34:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 16:29:34:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 16:29:34:   Generating L2A metadata...
    2025/06/02 16:29:35:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (288, 971, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (288, 971, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (288, 971, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    2025/06/02 16:29:36:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/06/02 16:29:36:   L2A product successfully written!
    2025/06/02 16:29:36:   Total runtime of the processing chain: 0:00:54.853475

##### Captured stderr call

    2025/06/02 16:28:41:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/06/02 16:28:44:   Statically using band 40 for co-registration.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.5% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.4% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.1% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.0% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.3% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.1% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.4% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.6% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.4% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.7% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.2% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.3% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.3% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.1% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.2% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.4% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.4% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.4% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.4% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.5% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.4% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.3% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 27.1% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 28.7% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 29.2% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 30.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 31.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 32.1% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 33.1% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 34.8% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 35.0% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 36.3% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 37.4% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 38.1% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 39.5% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 40.2% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 41.2% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 42.3% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 43.3% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 44.2% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 45.1% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 46.2% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 47.3% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 48.1% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 49.3% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 50.1% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 51.1% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 52.4% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 53.2% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 54.6% Complete  => 0:00:00
    Warping progress     |============================----------------------| 55.3% Complete  => 0:00:00
    Warping progress     |============================----------------------| 56.2% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.1% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 58.0% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 59.3% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 60.5% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 61.9% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 62.4% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.0% Complete  => 0:00:00
    Warping progress     |================================------------------| 64.3% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 65.2% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.7% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.2% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.2% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.5% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.3% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.3% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.1% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.0% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.2% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.1% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.3% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.2% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.3% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.1% Complete  => 0:00:00
    Warping progress     |============================================------| 87.0% Complete  => 0:00:00
    Warping progress     |============================================------| 88.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.2% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.1% Complete  => 0:00:00
    Warping progress     |================================================--| 96.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.1% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:08
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.9% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 2.5% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 3.7% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 4.3% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 5.0% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 5.6% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 6.2% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 6.8% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 7.5% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 8.1% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 8.7% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 9.3% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 9.9% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 10.6% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 11.2% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 11.8% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 12.4% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 13.0% Complete  => 0:00:10
    	progress: |=======-------------------------------------------| 13.7% Complete  => 0:00:10
    	progress: |=======-------------------------------------------| 14.3% Complete  => 0:00:10
    	progress: |=======-------------------------------------------| 14.9% Complete  => 0:00:10
    	progress: |========------------------------------------------| 15.5% Complete  => 0:00:10
    	progress: |========------------------------------------------| 16.1% Complete  => 0:00:10
    	progress: |========------------------------------------------| 16.8% Complete  => 0:00:10
    	progress: |=========-----------------------------------------| 17.4% Complete  => 0:00:10
    	progress: |=========-----------------------------------------| 18.0% Complete  => 0:00:10
    	progress: |=========-----------------------------------------| 18.6% Complete  => 0:00:10
    	progress: |==========----------------------------------------| 19.3% Complete  => 0:00:10
    	progress: |==========----------------------------------------| 19.9% Complete  => 0:00:10
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 22.4% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 23.0% Complete  => 0:00:10
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:10
    	progress: |============--------------------------------------| 24.2% Complete  => 0:00:10
    	progress: |============--------------------------------------| 24.8% Complete  => 0:00:10
    	progress: |=============-------------------------------------| 25.5% Complete  => 0:00:10
    	progress: |=============-------------------------------------| 26.1% Complete  => 0:00:10
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:10
    	progress: |==============------------------------------------| 27.3% Complete  => 0:00:10
    	progress: |==============------------------------------------| 28.0% Complete  => 0:00:10
    	progress: |==============------------------------------------| 28.6% Complete  => 0:00:10
    	progress: |===============-----------------------------------| 29.2% Complete  => 0:00:10
    	progress: |===============-----------------------------------| 29.8% Complete  => 0:00:10
    	progress: |===============-----------------------------------| 30.4% Complete  => 0:00:10
    	progress: |================----------------------------------| 31.1% Complete  => 0:00:10
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:10
    	progress: |================----------------------------------| 32.3% Complete  => 0:00:10
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:10
    	progress: |=================---------------------------------| 33.5% Complete  => 0:00:10
    	progress: |=================---------------------------------| 34.2% Complete  => 0:00:10
    	progress: |=================---------------------------------| 34.8% Complete  => 0:00:10
    	progress: |==================--------------------------------| 35.4% Complete  => 0:00:10
    	progress: |==================--------------------------------| 36.0% Complete  => 0:00:10
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:10
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:10
    	progress: |===================-------------------------------| 37.9% Complete  => 0:00:10
    	progress: |===================-------------------------------| 38.5% Complete  => 0:00:10
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:10
    	progress: |====================------------------------------| 39.8% Complete  => 0:00:10
    	progress: |====================------------------------------| 40.4% Complete  => 0:00:10
    	progress: |====================------------------------------| 41.0% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 41.6% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 42.9% Complete  => 0:00:10
    	progress: |======================----------------------------| 43.5% Complete  => 0:00:10
    	progress: |======================----------------------------| 44.1% Complete  => 0:00:10
    	progress: |======================----------------------------| 44.7% Complete  => 0:00:10
    	progress: |=======================---------------------------| 45.3% Complete  => 0:00:10
    	progress: |=======================---------------------------| 46.0% Complete  => 0:00:10
    	progress: |=======================---------------------------| 46.6% Complete  => 0:00:10
    	progress: |========================--------------------------| 47.2% Complete  => 0:00:10
    	progress: |========================--------------------------| 47.8% Complete  => 0:00:10
    	progress: |========================--------------------------| 48.4% Complete  => 0:00:10
    	progress: |=========================-------------------------| 49.1% Complete  => 0:00:10
    	progress: |=========================-------------------------| 49.7% Complete  => 0:00:10
    	progress: |=========================-------------------------| 50.3% Complete  => 0:00:10
    	progress: |=========================-------------------------| 50.9% Complete  => 0:00:10
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:10
    	progress: |==========================------------------------| 52.2% Complete  => 0:00:10
    	progress: |==========================------------------------| 52.8% Complete  => 0:00:10
    	progress: |===========================-----------------------| 53.4% Complete  => 0:00:10
    	progress: |===========================-----------------------| 54.0% Complete  => 0:00:10
    	progress: |===========================-----------------------| 54.7% Complete  => 0:00:10
    	progress: |============================----------------------| 55.3% Complete  => 0:00:10
    	progress: |============================----------------------| 55.9% Complete  => 0:00:10
    	progress: |============================----------------------| 56.5% Complete  => 0:00:10
    	progress: |=============================---------------------| 57.1% Complete  => 0:00:10
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:10
    	progress: |=============================---------------------| 58.4% Complete  => 0:00:10
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:10
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:10
    	progress: |==============================--------------------| 60.2% Complete  => 0:00:10
    	progress: |==============================--------------------| 60.9% Complete  => 0:00:10
    	progress: |===============================-------------------| 61.5% Complete  => 0:00:10
    	progress: |===============================-------------------| 62.1% Complete  => 0:00:10
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:10
    	progress: |================================------------------| 63.4% Complete  => 0:00:10
    	progress: |================================------------------| 64.0% Complete  => 0:00:10
    	progress: |================================------------------| 64.6% Complete  => 0:00:10
    	progress: |=================================-----------------| 65.2% Complete  => 0:00:10
    	progress: |=================================-----------------| 65.8% Complete  => 0:00:10
    	progress: |=================================-----------------| 66.5% Complete  => 0:00:10
    	progress: |==================================----------------| 67.1% Complete  => 0:00:10
    	progress: |==================================----------------| 67.7% Complete  => 0:00:10
    	progress: |==================================----------------| 68.3% Complete  => 0:00:10
    	progress: |==================================----------------| 68.9% Complete  => 0:00:10
    	progress: |===================================---------------| 69.6% Complete  => 0:00:10
    	progress: |===================================---------------| 70.2% Complete  => 0:00:10
    	progress: |===================================---------------| 70.8% Complete  => 0:00:10
    	progress: |====================================--------------| 71.4% Complete  => 0:00:10
    	progress: |====================================--------------| 72.0% Complete  => 0:00:10
    	progress: |====================================--------------| 72.7% Complete  => 0:00:10
    	progress: |=====================================-------------| 73.3% Complete  => 0:00:10
    	progress: |=====================================-------------| 73.9% Complete  => 0:00:10
    	progress: |=====================================-------------| 74.5% Complete  => 0:00:10
    	progress: |======================================------------| 75.2% Complete  => 0:00:10
    	progress: |======================================------------| 75.8% Complete  => 0:00:10
    	progress: |======================================------------| 76.4% Complete  => 0:00:10
    	progress: |=======================================-----------| 77.0% Complete  => 0:00:10
    	progress: |=======================================-----------| 77.6% Complete  => 0:00:10
    	progress: |=======================================-----------| 78.3% Complete  => 0:00:10
    	progress: |=======================================-----------| 78.9% Complete  => 0:00:10
    	progress: |========================================----------| 79.5% Complete  => 0:00:10
    	progress: |========================================----------| 80.1% Complete  => 0:00:10
    	progress: |========================================----------| 80.7% Complete  => 0:00:10
    	progress: |=========================================---------| 81.4% Complete  => 0:00:10
    	progress: |=========================================---------| 82.0% Complete  => 0:00:10
    	progress: |=========================================---------| 82.6% Complete  => 0:00:10
    	progress: |==========================================--------| 83.2% Complete  => 0:00:10
    	progress: |==========================================--------| 83.9% Complete  => 0:00:10
    	progress: |==========================================--------| 84.5% Complete  => 0:00:10
    	progress: |===========================================-------| 85.1% Complete  => 0:00:10
    	progress: |===========================================-------| 85.7% Complete  => 0:00:10
    	progress: |===========================================-------| 86.3% Complete  => 0:00:10
    	progress: |===========================================-------| 87.0% Complete  => 0:00:10
    	progress: |============================================------| 87.6% Complete  => 0:00:10
    	progress: |============================================------| 88.2% Complete  => 0:00:10
    	progress: |============================================------| 88.8% Complete  => 0:00:10
    	progress: |=============================================-----| 89.4% Complete  => 0:00:10
    	progress: |=============================================-----| 90.1% Complete  => 0:00:10
    	progress: |=============================================-----| 90.7% Complete  => 0:00:10
    	progress: |==============================================----| 91.3% Complete  => 0:00:10
    	progress: |==============================================----| 91.9% Complete  => 0:00:10
    	progress: |==============================================----| 92.5% Complete  => 0:00:10
    	progress: |===============================================---| 93.2% Complete  => 0:00:10
    	progress: |===============================================---| 93.8% Complete  => 0:00:10
    	progress: |===============================================---| 94.4% Complete  => 0:00:10
    	progress: |================================================--| 95.0% Complete  => 0:00:10
    	progress: |================================================--| 95.7% Complete  => 0:00:10
    	progress: |================================================--| 96.3% Complete  => 0:00:10
    	progress: |================================================--| 96.9% Complete  => 0:00:10
    	progress: |=================================================-| 97.5% Complete  => 0:00:10
    	progress: |=================================================-| 98.1% Complete  => 0:00:10
    	progress: |=================================================-| 98.8% Complete  => 0:00:10
    	progress: |==================================================| 99.4% Complete  => 0:00:10
    	progress: |==================================================| 100.0% Complete  => 0:00:10

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.9% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.3% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 2.7% Complete  => 0:00:00
    	progress: |==------------------------------------------------| 4.4% Complete  => 0:00:00
    	progress: |====----------------------------------------------| 8.4% Complete  => 0:00:00
    	progress: |=========-----------------------------------------| 18.7% Complete  => 0:00:00
    	progress: |=============-------------------------------------| 25.8% Complete  => 0:00:00
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:00
    	progress: |=====================================-------------| 74.7% Complete  => 0:00:01
    	progress: |============================================------| 87.1% Complete  => 0:00:01
    	progress: |==================================================| 100.0% Complete  => 0:00:01
    2025/06/02 16:29:31:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 16:29:31:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 16:29:36:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/02 16:29:36:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:29:36:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:29:36:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_import_polymer 0:00:00.038633

Started | 2025-06-02 16:29:36
Ended | 2025-06-02 16:29:36
Duration | 0:00:00.038633
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_run_all_processors 0:01:21.988644

Started | 2025-06-02 16:29:36
Ended | 2025-06-02 16:30:58
Duration | 0:01:21.988644
Markers | skipif False reason='POLYMER is not installed.'
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': None,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmphahooe8w'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'combined',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '/root/polymer-v4.16.1',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spectral',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': True},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/02 16:29:36:   Reading metadata for VNIR detector...
    2025/06/02 16:29:37:   Calculating solar irradiance...
    2025/06/02 16:29:37:   Reading metadata for SWIR detector...
    2025/06/02 16:29:37:   Calculating solar irradiance...
    2025/06/02 16:29:37:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:29:37:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:29:37:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:29:37:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:29:37:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:29:38:   Computing VNIR geolayer...
    2025/06/02 16:29:38:   Computing SWIR geolayer...
    2025/06/02 16:29:38:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 16:29:38:   Percentage of defective pixels: 0.49
    2025/06/02 16:29:38:   Percentage of pixels with a defect in any band: 35.60
    2025/06/02 16:29:38:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 16:29:38:   Percentage of defective pixels: 0.50
    2025/06/02 16:29:38:   Percentage of pixels with a defect in any band: 44.50
    2025/06/02 16:29:39:   Pre-processing DEM for VNIR...
    2025/06/02 16:29:39:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/06/02 16:29:39:   Pre-processing DEM for SWIR...
    2025/06/02 16:29:39:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/06/02 16:29:39:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/06/02 16:29:39:   Starting atmospheric correction for VNIR and SWIR detector in 'combined' mode. Source radiometric unit code is 'TOARad'.
    2025/06/02 16:29:39:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 16,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': True,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/06/02 16:29:39:   Setting up forward operator...
    2025/06/02 16:29:39:   SICOR is applied to land pixels only. This may result in edge effects, e.g., at coastlines...
    2025/06/02 16:29:40:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/06/02 16:29:41:   Getting observation metadata...
    2025/06/02 16:29:41:   Checking if observation metadata values are within LUT value ranges...
    2025/06/02 16:29:41:   Loading solar irradiance model...
    2025/06/02 16:29:41:   Loading RT LUT...
    2025/06/02 16:29:41:   LUT file was properly downloaded and is available for AC!
    2025/06/02 16:29:41:   Converting LUT to Fontenla solar model...
    2025/06/02 16:29:42:   Resampling LUT to EnMAP wavelengths...
    2025/06/02 16:30:02:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/06/02 16:30:02:   Calculating absorption coefficients of liquid water and ice...
    2025/06/02 16:30:02:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/06/02 16:30:03:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/06/02 16:30:04:   Performing first guess liquid water retrieval based on the NDWI...
    2025/06/02 16:30:04:   Performing first guess ice retrieval based on the NDSI...
    2025/06/02 16:30:04:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/06/02 16:30:04:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/06/02 16:30:04:   Preparing segmented SWIR L1B data cube...
    2025/06/02 16:30:04:   Performing 3 phases of water retrieval...
    2025/06/02 16:30:04:   Setting up multiprocessing...
    2025/06/02 16:30:04:   Multiprocessing on 16 cpu's
    2025/06/02 16:30:04:   Preparing optimal estimation input...
    2025/06/02 16:30:04:   Optimization...
    2025/06/02 16:30:05:   Done!
    2025/06/02 16:30:05:   Runtime: 1.45 s
    2025/06/02 16:30:05:   Smoothing segmented CWV retrieval map...
    2025/06/02 16:30:05:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/06/02 16:30:06:   Starting surface reflectance retrieval...
    2025/06/02 16:30:06:   Calculating surface reflectance for vnir detector...
    2025/06/02 16:30:07:   Calculating surface reflectance for swir detector...
    2025/06/02 16:30:09:   Smoothing segmented liquid water and ice maps...
    2025/06/02 16:30:09:   SICOR atmospheric correction for EnMAP in combined mode successfully finished!
    vnir
    2025/06/02 16:30:09:   Running polymer...
    Initializing ENMAP product of size (30, 1000)
    2025/06/02 16:30:09:   Landmask is EnMAP L1B
    Starting processing at 2025-06-02 16:30:09.783588
    Processing block: size (30, 1000), offset (0, 0)
    Done in 0:00:44.014210
    2025/06/02 16:30:53:   Joining results of atmospheric correction.
    2025/06/02 16:30:53:   Re-applying dead pixel correction to correct for spectral spikes due to fringe effect.
    2025/06/02 16:30:53:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 16:30:54:   Percentage of defective pixels: 0.49
    2025/06/02 16:30:54:   Percentage of pixels with a defect in any band: 35.60
    2025/06/02 16:30:54:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 16:30:54:   Percentage of defective pixels: 0.50
    2025/06/02 16:30:54:   Percentage of pixels with a defect in any band: 44.50
    2025/06/02 16:30:54:   Starting orthorectification...
    2025/06/02 16:30:54:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (637410.0, 4942680.0, 666180.0, 4949340.0)
    2025/06/02 16:30:54:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:30:54:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:30:55:   Merging VNIR and SWIR data...
    2025/06/02 16:30:55:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 16:30:55:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 16:30:55:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 16:30:55:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 16:30:56:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 16:30:56:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 16:30:56:   Orthorectifying 'polymer_logchl' attribute...
    2025/06/02 16:30:56:   Orthorectifying 'polymer_logfb' attribute...
    2025/06/02 16:30:56:   Orthorectifying 'polymer_rgli' attribute...
    2025/06/02 16:30:56:   Orthorectifying 'polymer_rnir' attribute...
    2025/06/02 16:30:56:   Orthorectifying 'polymer_bitmask' attribute...
    2025/06/02 16:30:57:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 16:30:57:   Generating L2A metadata...
    2025/06/02 16:30:57:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (222, 959, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_LOGCHL.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_LOGFB.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_RGLI.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_RNIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_BITMASK.TIF.
    2025/06/02 16:30:58:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/06/02 16:30:58:   L2A product successfully written!
    2025/06/02 16:30:58:   Total runtime of the processing chain: 0:01:21.919999

##### Captured stderr call

    2025/06/02 16:29:36:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

    	progress: |=-------------------------------------------------| 2.4% Complete  => 0:00:00
    	progress: |==------------------------------------------------| 4.9% Complete  => 0:00:00
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:00
    	progress: |==================================================| 100.0% Complete  => 0:00:00
    2025/06/02 16:30:09:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 16:30:09:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 16:30:58:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/02 16:30:58:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:30:58:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:30:58:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_run_all_processors_without_acwater_installed 0:00:34.781136

Test to run all processors while replacing polymer_ac_enmap with None using mock.patch.

Started | 2025-06-02 16:30:58
Ended | 2025-06-02 16:31:33
Duration | 0:00:34.781136
Markers | skipif False reason='POLYMER is not installed.'
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': None,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmp_357s_4z'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'combined',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '/root/polymer-v4.16.1',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spectral',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': True},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/02 16:30:58:   Reading metadata for VNIR detector...
    2025/06/02 16:30:59:   Calculating solar irradiance...
    2025/06/02 16:30:59:   Reading metadata for SWIR detector...
    2025/06/02 16:30:59:   Calculating solar irradiance...
    2025/06/02 16:30:59:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:30:59:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:30:59:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:30:59:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:31:00:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:31:00:   Computing VNIR geolayer...
    2025/06/02 16:31:00:   Computing SWIR geolayer...
    2025/06/02 16:31:00:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 16:31:00:   Percentage of defective pixels: 0.49
    2025/06/02 16:31:00:   Percentage of pixels with a defect in any band: 35.60
    2025/06/02 16:31:00:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 16:31:00:   Percentage of defective pixels: 0.50
    2025/06/02 16:31:00:   Percentage of pixels with a defect in any band: 44.50
    2025/06/02 16:31:00:   Pre-processing DEM for VNIR...
    2025/06/02 16:31:00:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/06/02 16:31:00:   Pre-processing DEM for SWIR...
    2025/06/02 16:31:00:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/06/02 16:31:00:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/06/02 16:31:01:   Starting atmospheric correction for VNIR and SWIR detector in 'combined' mode. Source radiometric unit code is 'TOARad'.
    2025/06/02 16:31:01:   Running atmospheric correction in 'land' mode, i.e., SICOR is applied to ALL surfaces. Uncertainty is expected for water surfaces because SICOR is designed for land only.
    2025/06/02 16:31:01:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 16,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': False,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/06/02 16:31:01:   Setting up forward operator...
    2025/06/02 16:31:01:   SICOR is applied to land AND water pixels.
    2025/06/02 16:31:01:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/06/02 16:31:02:   Getting observation metadata...
    2025/06/02 16:31:02:   Checking if observation metadata values are within LUT value ranges...
    2025/06/02 16:31:02:   Loading solar irradiance model...
    2025/06/02 16:31:02:   Loading RT LUT...
    2025/06/02 16:31:02:   LUT file was properly downloaded and is available for AC!
    2025/06/02 16:31:02:   Converting LUT to Fontenla solar model...
    2025/06/02 16:31:02:   Resampling LUT to EnMAP wavelengths...
    2025/06/02 16:31:21:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/06/02 16:31:21:   Calculating absorption coefficients of liquid water and ice...
    2025/06/02 16:31:22:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/06/02 16:31:23:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/06/02 16:31:23:   Performing first guess liquid water retrieval based on the NDWI...
    2025/06/02 16:31:23:   Performing first guess ice retrieval based on the NDSI...
    2025/06/02 16:31:23:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/06/02 16:31:23:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/06/02 16:31:23:   Preparing segmented SWIR L1B data cube...
    2025/06/02 16:31:23:   Performing 3 phases of water retrieval...
    2025/06/02 16:31:23:   Setting up multiprocessing...
    2025/06/02 16:31:23:   Multiprocessing on 16 cpu's
    2025/06/02 16:31:23:   Preparing optimal estimation input...
    2025/06/02 16:31:23:   Optimization...
    2025/06/02 16:31:25:   Done!
    2025/06/02 16:31:25:   Runtime: 2.12 s
    2025/06/02 16:31:25:   Smoothing segmented CWV retrieval map...
    2025/06/02 16:31:25:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/06/02 16:31:26:   Starting surface reflectance retrieval...
    2025/06/02 16:31:26:   Calculating surface reflectance for vnir detector...
    2025/06/02 16:31:27:   Calculating surface reflectance for swir detector...
    2025/06/02 16:31:29:   Smoothing segmented liquid water and ice maps...
    2025/06/02 16:31:29:   SICOR atmospheric correction for EnMAP in land mode successfully finished!
    2025/06/02 16:31:29:   Joining results of atmospheric correction.
    2025/06/02 16:31:29:   Re-applying dead pixel correction to correct for spectral spikes due to fringe effect.
    2025/06/02 16:31:29:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 16:31:29:   Percentage of defective pixels: 0.49
    2025/06/02 16:31:29:   Percentage of pixels with a defect in any band: 35.60
    2025/06/02 16:31:29:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 16:31:29:   Percentage of defective pixels: 0.50
    2025/06/02 16:31:29:   Percentage of pixels with a defect in any band: 44.50
    2025/06/02 16:31:30:   Starting orthorectification...
    2025/06/02 16:31:30:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (637410.0, 4942680.0, 666180.0, 4949340.0)
    2025/06/02 16:31:30:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:31:30:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:31:31:   Merging VNIR and SWIR data...
    2025/06/02 16:31:31:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 16:31:31:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 16:31:31:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 16:31:31:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 16:31:31:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 16:31:31:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 16:31:32:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 16:31:32:   Generating L2A metadata...
    2025/06/02 16:31:32:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (222, 959, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    2025/06/02 16:31:33:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/06/02 16:31:33:   L2A product successfully written!
    2025/06/02 16:31:33:   Total runtime of the processing chain: 0:00:34.730134

##### Captured stderr call

    2025/06/02 16:30:58:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/06/02 16:31:01:   Polymer is not callable. As a fallback, SICOR is applied to water surfaces instead.

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |==------------------------------------------------| 3.0% Complete  => 0:00:00
    	progress: |===-----------------------------------------------| 5.4% Complete  => 0:00:00
    	progress: |=====---------------------------------------------| 10.2% Complete  => 0:00:00
    	progress: |========------------------------------------------| 16.3% Complete  => 0:00:00
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:00
    	progress: |=================---------------------------------| 33.1% Complete  => 0:00:00
    	progress: |===========================-----------------------| 53.0% Complete  => 0:00:00
    	progress: |==============================--------------------| 60.8% Complete  => 0:00:01
    	progress: |====================================--------------| 72.9% Complete  => 0:00:01
    	progress: |============================================------| 88.0% Complete  => 0:00:01
    	progress: |==================================================| 99.4% Complete  => 0:00:01
    	progress: |==================================================| 100.0% Complete  => 0:00:01
    2025/06/02 16:31:29:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 16:31:29:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 16:31:33:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/02 16:31:33:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:31:33:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:31:33:   The 'polymer_logchl' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:31:33:   The 'polymer_logfb' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:31:33:   The 'polymer_rgli' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:31:33:   The 'polymer_rnir' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:31:33:   The 'polymer_bitmask' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 16:31:33:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

## tests/test_dead_pixel_correction.py 15 0:00:10.928755

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_2D_deadpixelmap_spatial 0:00:03.939420

Started | 2025-06-02 16:31:33
Ended | 2025-06-02 16:31:37
Duration | 0:00:03.939420
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_2D_deadpixelmap_spectral 0:00:00.097192

Started | 2025-06-02 16:31:37
Ended | 2025-06-02 16:31:37
Duration | 0:00:00.097192
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_3D_deadpixelmap_spatial 0:00:06.642262

Started | 2025-06-02 16:31:37
Ended | 2025-06-02 16:31:44
Duration | 0:00:06.642262
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_3D_deadpixelmap_spectral 0:00:00.169862

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.169862
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_axis_0 0:00:00.003090

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.003090
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_axis_1 0:00:00.002678

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.002678
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_bad_args 0:00:00.001238

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.001238
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_2d 0:00:00.001964

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.001964
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_0 0:00:00.002820

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.002820
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_1 0:00:00.003589

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.003589
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_2 0:00:00.052950

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.052950
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_bad_args 0:00:00.001125

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.001125
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_bad_args 0:00:00.001229

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.001229
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_interpolation_pandas 0:00:00.004599

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.004599
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_interpolation_scipy 0:00:00.004736

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.004736
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_dem_preprocessing.py 8 0:00:00.396678

### PASSED Test_DEM_Processor::test_compute_aspect 0:00:00.061431

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.061431
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_compute_slopes 0:00:00.027143

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.027143
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_fill_gaps 0:00:00.023683

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.023683
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_get_flat_dem 0:00:00.032790

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.032790
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_demTooSmall 0:00:00.034867

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.034867
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_noWGS84 0:00:00.024990

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.024990
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_nomapinfo 0:00:00.022982

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.022982
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_to_sensor_geometry 0:00:00.168789

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:44
Duration | 0:00:00.168789
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_images_sensorgeo.py 6 0:00:23.625584

### PASSED Test_EnMAPL1Product_SensorGeo::test_set_SWIRattr_with_transformedVNIRattr 0:00:02.292523

Started | 2025-06-02 16:31:44
Ended | 2025-06-02 16:31:47
Duration | 0:00:02.292523
Markers |
Fixtures | request

#### Setup

##### Captured stdout setup

    2025/06/02 16:31:45:   Reading metadata for VNIR detector...
    2025/06/02 16:31:45:   Calculating solar irradiance...
    2025/06/02 16:31:45:   Reading metadata for SWIR detector...
    2025/06/02 16:31:45:   Calculating solar irradiance...
    2025/06/02 16:31:45:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:31:46:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:31:46:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:31:46:   Computing VNIR geolayer...
    2025/06/02 16:31:46:   Computing SWIR geolayer...

##### Captured stderr setup

    2025/06/02 16:31:44:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

#### Call

##### Captured stdout call

    2025/06/02 16:31:46:   Transforming the 'mask_snow' attribute from VNIR to SWIR sensor geometry.

##### Captured stderr call

    2025/06/02 16:31:46:   The mask_snow is not yet available in SWIR sensor geometry. Use EnMAP_SWIR_SensorGeo.transform_vnir_to_swir_raster() to set it with a transformed version of the one provided in VNIR sensor geometry.

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_set_SWIRattr_with_transformedVNIRattr__attrIsNone 0:00:00.007436

Started | 2025-06-02 16:31:47
Ended | 2025-06-02 16:31:47
Duration | 0:00:00.007436
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:31:47:   Transforming the 'mask_haze' attribute from VNIR to SWIR sensor geometry.

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_swir_to_vnir_raster__no_geolayer 0:00:00.010182

Started | 2025-06-02 16:31:47
Ended | 2025-06-02 16:31:47
Duration | 0:00:00.010182
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_swir_to_vnir_raster_no_keystone 0:00:01.914573

Started | 2025-06-02 16:31:47
Ended | 2025-06-02 16:31:48
Duration | 0:00:01.914573
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_vnir_to_swir_raster__no_geolayer 0:00:00.001148

Started | 2025-06-02 16:31:48
Ended | 2025-06-02 16:31:48
Duration | 0:00:00.001148
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_vnir_to_swir_raster_with_keystone 0:00:19.399722

Started | 2025-06-02 16:31:48
Ended | 2025-06-02 16:32:08
Duration | 0:00:19.399722
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_isofit_enmap.py 65 0:01:57.791154

### PASSED Test_ISOFIT_EnMAP::test__compute_cos_i 0:00:09.266031

Started | 2025-06-02 16:32:08
Ended | 2025-06-02 16:32:17
Duration | 0:00:09.266031
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:32:08:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/02 16:32:08:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 16:32:08:   LUT zipfile already downloaded. Proceeding.
    2025/06/02 16:32:08:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Pulling release v1.0.2
    Downloading file
    Unzipping /root/.isofit/isofit-data.zip
    Done, now available at: /root/.isofit/data
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Pulling release main/v1.2.7
    Downloading file
    Unzipping /root/.isofit/isofit-tutorials.zip
    Downloading NEON data for the example
    Output as: /root/.isofit/examples/isotuts/NEON/data
    Downloading file
    Unzipping /root/.isofit/examples/isotuts/NEON/NEON-subset-data.zip
    Done, now available at: /root/.isofit/examples
    [!] Be sure to build the examples for your system via `isofit build`

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test__compute_solar_phase 0:00:00.285886

Started | 2025-06-02 16:32:17
Ended | 2025-06-02 16:32:17
Duration | 0:00:00.285886
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:32:17:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/02 16:32:17:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 16:32:17:   LUT zipfile already downloaded. Proceeding.
    2025/06/02 16:32:17:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test__run__backtransformed_l2_spectra_6s 0:00:00.000755

4x3 spectra within 10x10 image. Lines: different forward sim.: #1: UVEG LUT; #2: Luis LUT, #3: MODTRAN.

Started | 2025-06-02 16:32:17
Ended | 2025-06-02 16:32:17
Duration | 0:00:00.000755
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 185, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test__run__backtransformed_l2_spectra_lut_mod5 0:01:12.353477

4x3 spectra within 10x10 image. Lines: different forward sim.: #1: UVEG LUT; #2: Luis LUT, #3: MODTRAN.

Started | 2025-06-02 16:32:17
Ended | 2025-06-02 16:33:30
Duration | 0:01:12.353477
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:32:18:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/02 16:32:18:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 16:32:18:   LUT zipfile already downloaded. Proceeding.
    2025/06/02 16:32:18:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    2025/06/02 16:32:18:   Generating LUT file...
    2025/06/02 16:32:28:   Flightline ID: 20220717T110603Z
    2025/06/02 16:32:28:   no noise path found, proceeding without
    2025/06/02 16:32:28:   Running ISOFIT...
    2025/06/02 16:32:28:   Loading config file: /tmp/tmplew76x19/workdir/config/isofit_config.json
    2025/06/02 16:32:28:   Checking config sections for configuration issues
    2025/06/02 16:32:28:   Configuration file checks complete, no errors found.
    2025/06/02 16:32:37:   Building first forward model, will generate any necessary LUTs
    2025/06/02 16:32:37:   Loading from wavelength_file: /tmp/tmplew76x19/extracted/backtransformed_l2_spectra_v9/enmap_wavelengths.txt
    2025/06/02 16:32:37:   Prebuilt LUT provided
    2025/06/02 16:32:49:   Loading LUT into memory
    2025/06/02 16:32:50:   LUT grid loaded from file: OrderedDict({'AERFRAC_2': [0.05, 0.12, 0.2, 0.3, 0.4, 0.8], 'H2OSTR': [0.0, 1.0, 1.5, 2.0, 2.7, 3.5, 5.0], 'observer_zenith': [0, 10.0, 20.0, 30.0, 40.0], 'relative_azimuth': [0, 25.0, 50.0, 85.0, 120.0, 155.0, 180.0], 'solar_zenith': [0, 10.0, 20.0, 35.0, 50.0, 70.0], 'surface_elevation_km': [0, 0.7, 2.5, 8.0]})
    2025/06/02 16:33:07:   Beginning 100 inversions in 100 chunks using 20 cores
    2025/06/02 16:33:28:   Inversions complete.  20.37s total, 4.9094 spectra/s, 0.2455 spectra/s/core
    2025/06/02 16:33:28:   ISOFIT finished.
    2025/06/02 16:33:28:   Stopping ray.

##### Captured stderr call

    2025/06/02 16:32:28:
    ******************************************************************************************
    ! Number of threads is greater than 1 (currently: 24), this may greatly impact performance
    ! Please set this the environment variables 'MKL_NUM_THREADS' and 'OMP_NUM_THREADS' to '1'
    ******************************************************************************************
    2025-06-02 16:32:32,431	WARNING services.py:2070 -- WARNING: The object store is using /tmp instead of /dev/shm because /dev/shm has only 66887680 bytes available. This will harm performance! You may be able to free up space by deleting files in /dev/shm. If you are inside a Docker container, you can increase /dev/shm size by passing '--shm-size=10.24gb' to 'docker run' (or add it to the run_options list in a Ray cluster config). Make sure to set this to more than 30% of available RAM.
    2025-06-02 16:32:33,647	INFO worker.py:1852 -- Started a local Ray instance.
    WARNING: All log messages before absl::InitializeLog() is called are written to STDERR
    I0000 00:00:1748882008.535832     865 chttp2_transport.cc:1182] ipv4:172.17.0.14:42043: Got goaway [2] err=UNAVAILABLE:GOAWAY received; Error code: 2; Debug Text: Cancelling all calls {created_time:"2025-06-02T16:33:28.535814198+00:00", http2_error:2, grpc_status:14}

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_apply_oe__direct_call 0:00:00.000607

Started | 2025-06-02 16:33:30
Ended | 2025-06-02 16:33:30
Duration | 0:00:00.000607
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 120, 'Skipped: too slow for running in CI')

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_apply_oe_on_map_geometry 0:00:00.000465

Started | 2025-06-02 16:33:30
Ended | 2025-06-02 16:33:30
Duration | 0:00:00.000465
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 154, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test_download_isofit_resources 0:00:02.349903

Started | 2025-06-02 16:33:30
Ended | 2025-06-02 16:33:32
Duration | 0:00:02.349903
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:33:30:   ISOFIT surface spectra zipfile successfully downloaded.
    2025/06/02 16:33:32:   LUT zipfile successfully downloaded.
    2025/06/02 16:33:32:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 16:33:32:   LUT zipfile already downloaded. Proceeding.

##### Captured log call

    INFO     test_downloads:_isofit_downloads.py:83 ISOFIT surface spectra zipfile successfully downloaded.
    INFO     test_downloads:_isofit_downloads.py:83 LUT zipfile successfully downloaded.
    INFO     test_downloads:_isofit_downloads.py:87 ISOFIT surface spectra zipfile already downloaded. Proceeding.
    INFO     test_downloads:_isofit_downloads.py:87 LUT zipfile already downloaded. Proceeding.

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test_generate_input_files 0:00:22.768293

Started | 2025-06-02 16:33:32
Ended | 2025-06-02 16:33:55
Duration | 0:00:22.768293
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:33:32:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/02 16:33:32:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 16:33:32:   LUT zipfile already downloaded. Proceeding.
    2025/06/02 16:33:32:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    2025/06/02 16:33:33:   Reading Input Data
    2025/06/02 16:33:33:   Reading metadata for VNIR detector...
    2025/06/02 16:33:33:   Calculating solar irradiance...
    2025/06/02 16:33:33:   Reading metadata for SWIR detector...
    2025/06/02 16:33:33:   Calculating solar irradiance...
    2025/06/02 16:33:33:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:33:34:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:33:34:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:33:34:   Computing VNIR geolayer...
    2025/06/02 16:33:34:   Computing SWIR geolayer...
    2025/06/02 16:33:34:   Starting orthorectification...
    2025/06/02 16:33:34:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636990.0, 4940640.0, 666180.0, 4949340.0)
    2025/06/02 16:33:34:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:33:35:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:33:37:   Merging VNIR and SWIR data...
    2025/06/02 16:33:37:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 16:33:37:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 16:33:37:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 16:33:37:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 16:33:38:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 16:33:38:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 16:33:39:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 16:33:39:   Generating L2A metadata...
    2025/06/02 16:33:41:   Generating radiance file...
    Writing GeoArray of size (290, 973, 202) to /tmp/tmpouhk26gw/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_rdn.
    2025/06/02 16:33:42:   Generating location file...
    2025/06/02 16:33:42:   Pre-processing DEM in map geometry...
    Automatically detected nodata value for GeoArray 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER': 0.0
    Writing GeoArray of size (290, 973, 3) to /tmp/tmpouhk26gw/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_loc.
    2025/06/02 16:33:42:   Generating observation file...
    Writing GeoArray of size (290, 973, 11) to /tmp/tmpouhk26gw/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_obs.
    2025/06/02 16:33:42:   Generating wavelength file...
    2025/06/02 16:33:42:   Generating surface file for default set of surface coverage types...
    0 ['filtered_other']
    0 ['filtered_veg']
    0 ['filtered_ocean']
    0 ['surface_Liquids']
    1 ['surface_Liquids']
    2025/06/02 16:33:44:   Generating LUT file...

##### Captured stderr call

    2025/06/02 16:33:33:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.2% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.5% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.1% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.0% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.1% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.1% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.1% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.0% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.1% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.3% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.5% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.0% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.1% Complete  => 0:00:00
    Warping progress     |============================================------| 87.1% Complete  => 0:00:00
    Warping progress     |============================================------| 88.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.0% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.0% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.0% Complete  => 0:00:00
    Warping progress     |================================================--| 96.0% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.0% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.0% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_run_on_map_geometry 0:00:00.000541

Started | 2025-06-02 16:33:55
Ended | 2025-06-02 16:33:55
Duration | 0:00:00.000541
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 213, 'Skipped: too slow for running in CI')

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_run_on_map_geometry_no_segmentation 0:00:00.000716

Started | 2025-06-02 16:33:55
Ended | 2025-06-02 16:33:55
Duration | 0:00:00.000716
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 217, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_LUTTransformer::test_modtran_lut_to_netcdf 0:00:10.764478

Started | 2025-06-02 16:33:55
Ended | 2025-06-02 16:34:06
Duration | 0:00:10.764478
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stderr call

    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")

#### Teardown

## tests/test_l1b_reader.py 10 0:01:50.510207

### PASSED Test_L1B_Reader::test_append_100_lines 0:00:16.409704

Started | 2025-06-02 16:34:06
Ended | 2025-06-02 16:34:22
Duration | 0:00:16.409704
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:34:06:   Reading Input Data
    2025/06/02 16:34:06:   Reading metadata for VNIR detector...
    2025/06/02 16:34:07:   Calculating solar irradiance...
    2025/06/02 16:34:07:   Reading metadata for SWIR detector...
    2025/06/02 16:34:07:   Calculating solar irradiance...
    2025/06/02 16:34:07:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:07:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:07:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:07:   Reading metadata for VNIR detector...
    2025/06/02 16:34:07:   Calculating solar irradiance...
    2025/06/02 16:34:07:   Reading metadata for SWIR detector...
    2025/06/02 16:34:08:   Calculating solar irradiance...
    2025/06/02 16:34:08:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:08:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:08:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:08:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:08:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:08:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:08:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:08:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7ddvn6cg/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7ddvn6cg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7ddvn6cg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7ddvn6cg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7ddvn6cg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7ddvn6cg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7ddvn6cg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7ddvn6cg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:34:08:   L1B product successfully written!
    2025/06/02 16:34:08:   Reading Input Data
    2025/06/02 16:34:09:   Reading metadata for VNIR detector...
    2025/06/02 16:34:09:   Calculating solar irradiance...
    2025/06/02 16:34:09:   Reading metadata for SWIR detector...
    2025/06/02 16:34:09:   Calculating solar irradiance...
    2025/06/02 16:34:09:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:09:   Reading Input Data
    2025/06/02 16:34:09:   Reading metadata for VNIR detector...
    2025/06/02 16:34:09:   Calculating solar irradiance...
    2025/06/02 16:34:09:   Reading metadata for SWIR detector...
    2025/06/02 16:34:10:   Calculating solar irradiance...
    2025/06/02 16:34:10:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:10:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:10:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:10:   Reading metadata for VNIR detector...
    2025/06/02 16:34:10:   Calculating solar irradiance...
    2025/06/02 16:34:10:   Reading metadata for SWIR detector...
    2025/06/02 16:34:10:   Calculating solar irradiance...
    2025/06/02 16:34:10:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:10:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:10:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:11:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:11:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:11:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:11:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:11:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:34:12:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:34:12:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzh_lnnja/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzh_lnnja/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzh_lnnja/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzh_lnnja/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzh_lnnja/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzh_lnnja/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzh_lnnja/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzh_lnnja/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:34:13:   L1B product successfully written!
    2025/06/02 16:34:13:   Reading Input Data
    2025/06/02 16:34:13:   Reading metadata for VNIR detector...
    2025/06/02 16:34:13:   Calculating solar irradiance...
    2025/06/02 16:34:13:   Reading metadata for SWIR detector...
    2025/06/02 16:34:13:   Calculating solar irradiance...
    2025/06/02 16:34:13:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:13:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:34:15:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:34:15:   Reading Input Data
    2025/06/02 16:34:15:   Reading metadata for VNIR detector...
    2025/06/02 16:34:16:   Calculating solar irradiance...
    2025/06/02 16:34:16:   Reading metadata for SWIR detector...
    2025/06/02 16:34:16:   Calculating solar irradiance...
    2025/06/02 16:34:16:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:16:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:16:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:16:   Reading metadata for VNIR detector...
    2025/06/02 16:34:16:   Calculating solar irradiance...
    2025/06/02 16:34:16:   Reading metadata for SWIR detector...
    2025/06/02 16:34:17:   Calculating solar irradiance...
    2025/06/02 16:34:17:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:17:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:17:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:17:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:34:17:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:34:17:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp37jd4erx/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp37jd4erx/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp37jd4erx/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp37jd4erx/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp37jd4erx/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp37jd4erx/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp37jd4erx/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp37jd4erx/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 16:34:17:   L1B product successfully written!
    2025/06/02 16:34:17:   Reading Input Data
    2025/06/02 16:34:17:   Reading metadata for VNIR detector...
    2025/06/02 16:34:17:   Calculating solar irradiance...
    2025/06/02 16:34:17:   Reading metadata for SWIR detector...
    2025/06/02 16:34:18:   Calculating solar irradiance...
    2025/06/02 16:34:18:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:18:   Reading Input Data
    2025/06/02 16:34:18:   Reading metadata for VNIR detector...
    2025/06/02 16:34:18:   Calculating solar irradiance...
    2025/06/02 16:34:18:   Reading metadata for SWIR detector...
    2025/06/02 16:34:18:   Calculating solar irradiance...
    2025/06/02 16:34:18:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:18:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:18:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:19:   Reading metadata for VNIR detector...
    2025/06/02 16:34:19:   Calculating solar irradiance...
    2025/06/02 16:34:19:   Reading metadata for SWIR detector...
    2025/06/02 16:34:19:   Calculating solar irradiance...
    2025/06/02 16:34:19:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:19:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:19:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:19:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:34:19:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:34:19:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:34:20:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:34:20:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm13hovbj/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm13hovbj/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm13hovbj/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm13hovbj/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm13hovbj/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm13hovbj/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm13hovbj/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm13hovbj/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 16:34:21:   L1B product successfully written!
    2025/06/02 16:34:21:   Reading Input Data
    2025/06/02 16:34:21:   Reading metadata for VNIR detector...
    2025/06/02 16:34:21:   Calculating solar irradiance...
    2025/06/02 16:34:21:   Reading metadata for SWIR detector...
    2025/06/02 16:34:21:   Calculating solar irradiance...
    2025/06/02 16:34:21:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:21:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:34:22:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 16:34:08:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 16:34:08:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 16:34:08:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 16:34:08:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 16:34:08:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 16:34:08:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:34:08:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:34:08:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:34:08:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:34:08:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:34:11:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 16:34:11:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 16:34:11:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 16:34:11:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 16:34:11:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 16:34:12:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:34:13:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:34:13:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:34:13:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:34:13:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:34:17:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:34:17:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:34:17:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:34:17:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:34:17:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:34:17:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:34:17:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:34:19:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:34:19:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:34:20:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:34:20:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:34:20:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:34:20:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:34:20:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_10_lines 0:00:15.589476

Started | 2025-06-02 16:34:22
Ended | 2025-06-02 16:34:38
Duration | 0:00:15.589476
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:34:23:   Reading Input Data
    2025/06/02 16:34:23:   Reading metadata for VNIR detector...
    2025/06/02 16:34:23:   Calculating solar irradiance...
    2025/06/02 16:34:23:   Reading metadata for SWIR detector...
    2025/06/02 16:34:23:   Calculating solar irradiance...
    2025/06/02 16:34:23:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:23:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:23:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:24:   Reading metadata for VNIR detector...
    2025/06/02 16:34:24:   Calculating solar irradiance...
    2025/06/02 16:34:24:   Reading metadata for SWIR detector...
    2025/06/02 16:34:24:   Calculating solar irradiance...
    2025/06/02 16:34:24:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:24:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:24:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:24:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:24:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:24:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:24:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:24:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaizeik53/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaizeik53/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaizeik53/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaizeik53/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaizeik53/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaizeik53/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaizeik53/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaizeik53/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:34:25:   L1B product successfully written!
    2025/06/02 16:34:25:   Reading Input Data
    2025/06/02 16:34:25:   Reading metadata for VNIR detector...
    2025/06/02 16:34:25:   Calculating solar irradiance...
    2025/06/02 16:34:25:   Reading metadata for SWIR detector...
    2025/06/02 16:34:25:   Calculating solar irradiance...
    2025/06/02 16:34:25:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:25:   Reading Input Data
    2025/06/02 16:34:25:   Reading metadata for VNIR detector...
    2025/06/02 16:34:26:   Calculating solar irradiance...
    2025/06/02 16:34:26:   Reading metadata for SWIR detector...
    2025/06/02 16:34:26:   Calculating solar irradiance...
    2025/06/02 16:34:26:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:26:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:26:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:26:   Reading metadata for VNIR detector...
    2025/06/02 16:34:26:   Calculating solar irradiance...
    2025/06/02 16:34:26:   Reading metadata for SWIR detector...
    2025/06/02 16:34:27:   Calculating solar irradiance...
    2025/06/02 16:34:27:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:27:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:27:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:27:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:27:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:27:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:27:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:27:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:34:28:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:34:28:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwmjfzt88/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwmjfzt88/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwmjfzt88/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwmjfzt88/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwmjfzt88/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwmjfzt88/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwmjfzt88/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwmjfzt88/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:34:29:   L1B product successfully written!
    2025/06/02 16:34:29:   Reading Input Data
    2025/06/02 16:34:29:   Reading metadata for VNIR detector...
    2025/06/02 16:34:29:   Calculating solar irradiance...
    2025/06/02 16:34:29:   Reading metadata for SWIR detector...
    2025/06/02 16:34:29:   Calculating solar irradiance...
    2025/06/02 16:34:29:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:29:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:34:30:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:34:31:   Reading Input Data
    2025/06/02 16:34:31:   Reading metadata for VNIR detector...
    2025/06/02 16:34:31:   Calculating solar irradiance...
    2025/06/02 16:34:31:   Reading metadata for SWIR detector...
    2025/06/02 16:34:31:   Calculating solar irradiance...
    2025/06/02 16:34:31:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:31:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:32:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:32:   Reading metadata for VNIR detector...
    2025/06/02 16:34:32:   Calculating solar irradiance...
    2025/06/02 16:34:32:   Reading metadata for SWIR detector...
    2025/06/02 16:34:32:   Calculating solar irradiance...
    2025/06/02 16:34:32:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:32:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:32:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:32:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:34:32:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:34:32:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphc1nched/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphc1nched/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphc1nched/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphc1nched/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphc1nched/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphc1nched/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphc1nched/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphc1nched/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 16:34:33:   L1B product successfully written!
    2025/06/02 16:34:33:   Reading Input Data
    2025/06/02 16:34:33:   Reading metadata for VNIR detector...
    2025/06/02 16:34:33:   Calculating solar irradiance...
    2025/06/02 16:34:33:   Reading metadata for SWIR detector...
    2025/06/02 16:34:33:   Calculating solar irradiance...
    2025/06/02 16:34:33:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:33:   Reading Input Data
    2025/06/02 16:34:33:   Reading metadata for VNIR detector...
    2025/06/02 16:34:34:   Calculating solar irradiance...
    2025/06/02 16:34:34:   Reading metadata for SWIR detector...
    2025/06/02 16:34:34:   Calculating solar irradiance...
    2025/06/02 16:34:34:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:34:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:34:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:34:   Reading metadata for VNIR detector...
    2025/06/02 16:34:34:   Calculating solar irradiance...
    2025/06/02 16:34:34:   Reading metadata for SWIR detector...
    2025/06/02 16:34:35:   Calculating solar irradiance...
    2025/06/02 16:34:35:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:35:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:35:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:35:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:34:35:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:34:35:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:34:36:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:34:36:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvae4uav/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvae4uav/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvae4uav/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvae4uav/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvae4uav/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvae4uav/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvae4uav/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplvae4uav/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 16:34:36:   L1B product successfully written!
    2025/06/02 16:34:36:   Reading Input Data
    2025/06/02 16:34:36:   Reading metadata for VNIR detector...
    2025/06/02 16:34:36:   Calculating solar irradiance...
    2025/06/02 16:34:36:   Reading metadata for SWIR detector...
    2025/06/02 16:34:37:   Calculating solar irradiance...
    2025/06/02 16:34:37:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:37:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:34:38:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 16:34:24:   A minimum of 50 lines is required, only 10 were selected
    2025/06/02 16:34:24:   Set the number of line to 50
    2025/06/02 16:34:24:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 16:34:24:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 16:34:24:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 16:34:24:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 16:34:24:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 16:34:24:   A minimum of 50 lines is required, only 10 were selected
    2025/06/02 16:34:24:   Set the number of line to 50
    2025/06/02 16:34:25:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:34:25:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:34:25:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:34:25:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:34:25:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:34:27:   A minimum of 50 lines is required, only 10 were selected
    2025/06/02 16:34:27:   Set the number of line to 50
    2025/06/02 16:34:27:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 16:34:27:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 16:34:27:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 16:34:27:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 16:34:27:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 16:34:27:   A minimum of 50 lines is required, only 10 were selected
    2025/06/02 16:34:27:   Set the number of line to 50
    2025/06/02 16:34:28:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:34:28:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:34:28:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:34:28:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:34:28:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:34:32:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:34:32:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:34:33:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:34:33:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:34:33:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:34:33:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:34:33:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:34:35:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:34:35:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:34:36:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:34:36:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:34:36:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:34:36:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:34:36:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_150_lines 0:00:18.255096

Started | 2025-06-02 16:34:38
Ended | 2025-06-02 16:34:56
Duration | 0:00:18.255096
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:34:39:   Reading Input Data
    2025/06/02 16:34:39:   Reading metadata for VNIR detector...
    2025/06/02 16:34:39:   Calculating solar irradiance...
    2025/06/02 16:34:39:   Reading metadata for SWIR detector...
    2025/06/02 16:34:40:   Calculating solar irradiance...
    2025/06/02 16:34:40:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:40:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:40:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:40:   Reading metadata for VNIR detector...
    2025/06/02 16:34:40:   Calculating solar irradiance...
    2025/06/02 16:34:40:   Reading metadata for SWIR detector...
    2025/06/02 16:34:41:   Calculating solar irradiance...
    2025/06/02 16:34:41:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:41:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:41:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:41:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:41:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:41:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:41:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:41:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuhygdyxe/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuhygdyxe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuhygdyxe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuhygdyxe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuhygdyxe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuhygdyxe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuhygdyxe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuhygdyxe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:34:42:   L1B product successfully written!
    2025/06/02 16:34:42:   Reading Input Data
    2025/06/02 16:34:42:   Reading metadata for VNIR detector...
    2025/06/02 16:34:42:   Calculating solar irradiance...
    2025/06/02 16:34:42:   Reading metadata for SWIR detector...
    2025/06/02 16:34:42:   Calculating solar irradiance...
    2025/06/02 16:34:42:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:42:   Reading Input Data
    2025/06/02 16:34:43:   Reading metadata for VNIR detector...
    2025/06/02 16:34:43:   Calculating solar irradiance...
    2025/06/02 16:34:43:   Reading metadata for SWIR detector...
    2025/06/02 16:34:43:   Calculating solar irradiance...
    2025/06/02 16:34:43:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:43:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:43:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:43:   Reading metadata for VNIR detector...
    2025/06/02 16:34:44:   Calculating solar irradiance...
    2025/06/02 16:34:44:   Reading metadata for SWIR detector...
    2025/06/02 16:34:44:   Calculating solar irradiance...
    2025/06/02 16:34:44:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:44:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:44:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:44:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:44:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:44:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:44:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:44:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:34:46:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:34:46:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7zppipec/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7zppipec/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7zppipec/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7zppipec/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7zppipec/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7zppipec/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7zppipec/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7zppipec/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:34:47:   L1B product successfully written!
    2025/06/02 16:34:47:   Reading Input Data
    2025/06/02 16:34:47:   Reading metadata for VNIR detector...
    2025/06/02 16:34:47:   Calculating solar irradiance...
    2025/06/02 16:34:47:   Reading metadata for SWIR detector...
    2025/06/02 16:34:47:   Calculating solar irradiance...
    2025/06/02 16:34:47:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:47:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:34:49:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:34:49:   Reading Input Data
    2025/06/02 16:34:49:   Reading metadata for VNIR detector...
    2025/06/02 16:34:49:   Calculating solar irradiance...
    2025/06/02 16:34:49:   Reading metadata for SWIR detector...
    2025/06/02 16:34:50:   Calculating solar irradiance...
    2025/06/02 16:34:50:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:50:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:50:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:50:   Reading metadata for VNIR detector...
    2025/06/02 16:34:50:   Calculating solar irradiance...
    2025/06/02 16:34:50:   Reading metadata for SWIR detector...
    2025/06/02 16:34:51:   Calculating solar irradiance...
    2025/06/02 16:34:51:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:51:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:51:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:51:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:34:51:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:34:51:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp46n18dir/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp46n18dir/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp46n18dir/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp46n18dir/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp46n18dir/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp46n18dir/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp46n18dir/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp46n18dir/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 16:34:51:   L1B product successfully written!
    2025/06/02 16:34:51:   Reading Input Data
    2025/06/02 16:34:51:   Reading metadata for VNIR detector...
    2025/06/02 16:34:51:   Calculating solar irradiance...
    2025/06/02 16:34:51:   Reading metadata for SWIR detector...
    2025/06/02 16:34:52:   Calculating solar irradiance...
    2025/06/02 16:34:52:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:52:   Reading Input Data
    2025/06/02 16:34:52:   Reading metadata for VNIR detector...
    2025/06/02 16:34:52:   Calculating solar irradiance...
    2025/06/02 16:34:52:   Reading metadata for SWIR detector...
    2025/06/02 16:34:52:   Calculating solar irradiance...
    2025/06/02 16:34:52:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:52:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:52:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:53:   Reading metadata for VNIR detector...
    2025/06/02 16:34:53:   Calculating solar irradiance...
    2025/06/02 16:34:53:   Reading metadata for SWIR detector...
    2025/06/02 16:34:53:   Calculating solar irradiance...
    2025/06/02 16:34:53:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:53:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:53:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:53:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:34:53:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:34:53:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:34:54:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:34:54:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkrpdzz_m/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkrpdzz_m/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkrpdzz_m/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkrpdzz_m/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkrpdzz_m/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkrpdzz_m/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkrpdzz_m/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkrpdzz_m/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 16:34:54:   L1B product successfully written!
    2025/06/02 16:34:54:   Reading Input Data
    2025/06/02 16:34:54:   Reading metadata for VNIR detector...
    2025/06/02 16:34:55:   Calculating solar irradiance...
    2025/06/02 16:34:55:   Reading metadata for SWIR detector...
    2025/06/02 16:34:55:   Calculating solar irradiance...
    2025/06/02 16:34:55:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:55:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:34:56:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 16:34:41:   n_lines (150) exceeds the total number of line of second image
    2025/06/02 16:34:41:   Set to the image number of line
    2025/06/02 16:34:41:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 16:34:41:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 16:34:41:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 16:34:41:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 16:34:41:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 16:34:41:   n_lines (150) exceeds the total number of line of second image
    2025/06/02 16:34:41:   Set to the image number of line
    2025/06/02 16:34:42:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:34:42:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:34:42:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:34:42:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:34:42:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:34:44:   n_lines (150) exceeds the total number of line of second image
    2025/06/02 16:34:44:   Set to the image number of line
    2025/06/02 16:34:44:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 16:34:44:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 16:34:44:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 16:34:44:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 16:34:44:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 16:34:44:   n_lines (150) exceeds the total number of line of second image
    2025/06/02 16:34:44:   Set to the image number of line
    2025/06/02 16:34:46:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:34:46:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:34:46:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:34:46:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:34:46:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:34:51:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:34:51:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:34:51:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:34:51:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:34:51:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:34:51:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:34:51:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:34:53:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:34:53:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:34:54:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:34:54:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:34:54:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:34:54:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:34:54:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_50_lines 0:00:15.548720

Started | 2025-06-02 16:34:56
Ended | 2025-06-02 16:35:12
Duration | 0:00:15.548720
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:34:57:   Reading Input Data
    2025/06/02 16:34:57:   Reading metadata for VNIR detector...
    2025/06/02 16:34:57:   Calculating solar irradiance...
    2025/06/02 16:34:57:   Reading metadata for SWIR detector...
    2025/06/02 16:34:57:   Calculating solar irradiance...
    2025/06/02 16:34:57:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:57:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:57:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:57:   Reading metadata for VNIR detector...
    2025/06/02 16:34:58:   Calculating solar irradiance...
    2025/06/02 16:34:58:   Reading metadata for SWIR detector...
    2025/06/02 16:34:58:   Calculating solar irradiance...
    2025/06/02 16:34:58:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:58:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:34:58:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:34:58:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:58:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:58:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:58:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:34:58:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp47qssqvj/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp47qssqvj/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp47qssqvj/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp47qssqvj/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp47qssqvj/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp47qssqvj/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp47qssqvj/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp47qssqvj/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:34:59:   L1B product successfully written!
    2025/06/02 16:34:59:   Reading Input Data
    2025/06/02 16:34:59:   Reading metadata for VNIR detector...
    2025/06/02 16:34:59:   Calculating solar irradiance...
    2025/06/02 16:34:59:   Reading metadata for SWIR detector...
    2025/06/02 16:34:59:   Calculating solar irradiance...
    2025/06/02 16:34:59:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:34:59:   Reading Input Data
    2025/06/02 16:34:59:   Reading metadata for VNIR detector...
    2025/06/02 16:35:00:   Calculating solar irradiance...
    2025/06/02 16:35:00:   Reading metadata for SWIR detector...
    2025/06/02 16:35:00:   Calculating solar irradiance...
    2025/06/02 16:35:00:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:00:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:00:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:00:   Reading metadata for VNIR detector...
    2025/06/02 16:35:00:   Calculating solar irradiance...
    2025/06/02 16:35:00:   Reading metadata for SWIR detector...
    2025/06/02 16:35:01:   Calculating solar irradiance...
    2025/06/02 16:35:01:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:01:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:01:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:01:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:01:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:01:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:01:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:01:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:35:02:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:35:03:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpartrvtdd/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpartrvtdd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpartrvtdd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpartrvtdd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpartrvtdd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpartrvtdd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpartrvtdd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpartrvtdd/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:35:03:   L1B product successfully written!
    2025/06/02 16:35:03:   Reading Input Data
    2025/06/02 16:35:03:   Reading metadata for VNIR detector...
    2025/06/02 16:35:03:   Calculating solar irradiance...
    2025/06/02 16:35:03:   Reading metadata for SWIR detector...
    2025/06/02 16:35:03:   Calculating solar irradiance...
    2025/06/02 16:35:03:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:04:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:35:05:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:35:05:   Reading Input Data
    2025/06/02 16:35:05:   Reading metadata for VNIR detector...
    2025/06/02 16:35:05:   Calculating solar irradiance...
    2025/06/02 16:35:05:   Reading metadata for SWIR detector...
    2025/06/02 16:35:05:   Calculating solar irradiance...
    2025/06/02 16:35:05:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:05:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:06:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:06:   Reading metadata for VNIR detector...
    2025/06/02 16:35:06:   Calculating solar irradiance...
    2025/06/02 16:35:06:   Reading metadata for SWIR detector...
    2025/06/02 16:35:06:   Calculating solar irradiance...
    2025/06/02 16:35:06:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:06:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:06:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:06:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:35:06:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:35:06:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpka__u_cs/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpka__u_cs/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpka__u_cs/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpka__u_cs/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpka__u_cs/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpka__u_cs/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpka__u_cs/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpka__u_cs/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 16:35:07:   L1B product successfully written!
    2025/06/02 16:35:07:   Reading Input Data
    2025/06/02 16:35:07:   Reading metadata for VNIR detector...
    2025/06/02 16:35:07:   Calculating solar irradiance...
    2025/06/02 16:35:07:   Reading metadata for SWIR detector...
    2025/06/02 16:35:07:   Calculating solar irradiance...
    2025/06/02 16:35:07:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:07:   Reading Input Data
    2025/06/02 16:35:07:   Reading metadata for VNIR detector...
    2025/06/02 16:35:07:   Calculating solar irradiance...
    2025/06/02 16:35:08:   Reading metadata for SWIR detector...
    2025/06/02 16:35:08:   Calculating solar irradiance...
    2025/06/02 16:35:08:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:08:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:08:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:08:   Reading metadata for VNIR detector...
    2025/06/02 16:35:08:   Calculating solar irradiance...
    2025/06/02 16:35:08:   Reading metadata for SWIR detector...
    2025/06/02 16:35:09:   Calculating solar irradiance...
    2025/06/02 16:35:09:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:09:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:09:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:09:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:35:09:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:35:09:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:35:10:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:35:10:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv0mv5yzd/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv0mv5yzd/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv0mv5yzd/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv0mv5yzd/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv0mv5yzd/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv0mv5yzd/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv0mv5yzd/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv0mv5yzd/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 16:35:10:   L1B product successfully written!
    2025/06/02 16:35:10:   Reading Input Data
    2025/06/02 16:35:10:   Reading metadata for VNIR detector...
    2025/06/02 16:35:10:   Calculating solar irradiance...
    2025/06/02 16:35:10:   Reading metadata for SWIR detector...
    2025/06/02 16:35:10:   Calculating solar irradiance...
    2025/06/02 16:35:10:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:10:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:35:11:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 16:34:58:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 16:34:58:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 16:34:58:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 16:34:58:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 16:34:58:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 16:34:58:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:34:58:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:34:58:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:34:58:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:34:58:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:35:01:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 16:35:01:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 16:35:01:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 16:35:01:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 16:35:01:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 16:35:03:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:35:03:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:35:03:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:35:03:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:35:03:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:35:06:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:35:06:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:35:07:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:35:07:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:35:07:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:35:07:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:35:07:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:35:09:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:35:09:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:35:10:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:35:10:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:35:10:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:35:10:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:35:10:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_80_lines 0:00:16.431167

Started | 2025-06-02 16:35:12
Ended | 2025-06-02 16:35:28
Duration | 0:00:16.431167
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:35:12:   Reading Input Data
    2025/06/02 16:35:12:   Reading metadata for VNIR detector...
    2025/06/02 16:35:12:   Calculating solar irradiance...
    2025/06/02 16:35:12:   Reading metadata for SWIR detector...
    2025/06/02 16:35:13:   Calculating solar irradiance...
    2025/06/02 16:35:13:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:13:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:13:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:13:   Reading metadata for VNIR detector...
    2025/06/02 16:35:13:   Calculating solar irradiance...
    2025/06/02 16:35:13:   Reading metadata for SWIR detector...
    2025/06/02 16:35:13:   Calculating solar irradiance...
    2025/06/02 16:35:14:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:14:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:14:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:14:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:14:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:14:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:14:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:14:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj4smdffw/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (180, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj4smdffw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (180, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj4smdffw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj4smdffw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj4smdffw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (180, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj4smdffw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj4smdffw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj4smdffw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:35:14:   L1B product successfully written!
    2025/06/02 16:35:14:   Reading Input Data
    2025/06/02 16:35:14:   Reading metadata for VNIR detector...
    2025/06/02 16:35:14:   Calculating solar irradiance...
    2025/06/02 16:35:14:   Reading metadata for SWIR detector...
    2025/06/02 16:35:15:   Calculating solar irradiance...
    2025/06/02 16:35:15:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:15:   Reading Input Data
    2025/06/02 16:35:15:   Reading metadata for VNIR detector...
    2025/06/02 16:35:15:   Calculating solar irradiance...
    2025/06/02 16:35:15:   Reading metadata for SWIR detector...
    2025/06/02 16:35:16:   Calculating solar irradiance...
    2025/06/02 16:35:16:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:16:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:16:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:16:   Reading metadata for VNIR detector...
    2025/06/02 16:35:16:   Calculating solar irradiance...
    2025/06/02 16:35:16:   Reading metadata for SWIR detector...
    2025/06/02 16:35:16:   Calculating solar irradiance...
    2025/06/02 16:35:16:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:16:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:16:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:17:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:17:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:17:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:17:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:17:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:35:18:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:35:18:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpspbne2e9/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (180, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpspbne2e9/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (180, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpspbne2e9/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpspbne2e9/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpspbne2e9/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (180, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpspbne2e9/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpspbne2e9/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpspbne2e9/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:35:19:   L1B product successfully written!
    2025/06/02 16:35:19:   Reading Input Data
    2025/06/02 16:35:19:   Reading metadata for VNIR detector...
    2025/06/02 16:35:19:   Calculating solar irradiance...
    2025/06/02 16:35:19:   Reading metadata for SWIR detector...
    2025/06/02 16:35:19:   Calculating solar irradiance...
    2025/06/02 16:35:19:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:19:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:35:21:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:35:21:   Reading Input Data
    2025/06/02 16:35:21:   Reading metadata for VNIR detector...
    2025/06/02 16:35:21:   Calculating solar irradiance...
    2025/06/02 16:35:21:   Reading metadata for SWIR detector...
    2025/06/02 16:35:22:   Calculating solar irradiance...
    2025/06/02 16:35:22:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:22:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:22:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:22:   Reading metadata for VNIR detector...
    2025/06/02 16:35:22:   Calculating solar irradiance...
    2025/06/02 16:35:22:   Reading metadata for SWIR detector...
    2025/06/02 16:35:22:   Calculating solar irradiance...
    2025/06/02 16:35:22:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:22:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:22:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:23:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:35:23:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:35:23:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd3z0lmmp/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd3z0lmmp/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd3z0lmmp/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd3z0lmmp/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd3z0lmmp/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd3z0lmmp/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd3z0lmmp/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd3z0lmmp/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 16:35:23:   L1B product successfully written!
    2025/06/02 16:35:23:   Reading Input Data
    2025/06/02 16:35:23:   Reading metadata for VNIR detector...
    2025/06/02 16:35:23:   Calculating solar irradiance...
    2025/06/02 16:35:23:   Reading metadata for SWIR detector...
    2025/06/02 16:35:23:   Calculating solar irradiance...
    2025/06/02 16:35:23:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:23:   Reading Input Data
    2025/06/02 16:35:23:   Reading metadata for VNIR detector...
    2025/06/02 16:35:24:   Calculating solar irradiance...
    2025/06/02 16:35:24:   Reading metadata for SWIR detector...
    2025/06/02 16:35:24:   Calculating solar irradiance...
    2025/06/02 16:35:24:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:24:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:24:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:24:   Reading metadata for VNIR detector...
    2025/06/02 16:35:24:   Calculating solar irradiance...
    2025/06/02 16:35:24:   Reading metadata for SWIR detector...
    2025/06/02 16:35:25:   Calculating solar irradiance...
    2025/06/02 16:35:25:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:25:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:25:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:25:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:35:25:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:35:25:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:35:26:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:35:26:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3slxm_6k/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3slxm_6k/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3slxm_6k/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3slxm_6k/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3slxm_6k/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3slxm_6k/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3slxm_6k/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3slxm_6k/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 16:35:26:   L1B product successfully written!
    2025/06/02 16:35:26:   Reading Input Data
    2025/06/02 16:35:26:   Reading metadata for VNIR detector...
    2025/06/02 16:35:26:   Calculating solar irradiance...
    2025/06/02 16:35:26:   Reading metadata for SWIR detector...
    2025/06/02 16:35:26:   Calculating solar irradiance...
    2025/06/02 16:35:27:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:27:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:35:28:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 16:35:14:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 16:35:14:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 16:35:14:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 16:35:14:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 16:35:14:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 16:35:14:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:35:14:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:35:14:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:35:14:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:35:14:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:35:17:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 16:35:17:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 16:35:17:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 16:35:17:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 16:35:17:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 16:35:18:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:35:18:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:35:18:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:35:18:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:35:18:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:35:23:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:35:23:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:35:23:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:35:23:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:35:23:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:35:23:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:35:23:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:35:25:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:35:25:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:35:26:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:35:26:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:35:26:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:35:26:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:35:26:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_all_lines 0:00:18.379808

Started | 2025-06-02 16:35:28
Ended | 2025-06-02 16:35:46
Duration | 0:00:18.379808
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:35:29:   Reading Input Data
    2025/06/02 16:35:29:   Reading metadata for VNIR detector...
    2025/06/02 16:35:29:   Calculating solar irradiance...
    2025/06/02 16:35:29:   Reading metadata for SWIR detector...
    2025/06/02 16:35:29:   Calculating solar irradiance...
    2025/06/02 16:35:29:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:29:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:29:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:29:   Reading metadata for VNIR detector...
    2025/06/02 16:35:30:   Calculating solar irradiance...
    2025/06/02 16:35:30:   Reading metadata for SWIR detector...
    2025/06/02 16:35:30:   Calculating solar irradiance...
    2025/06/02 16:35:30:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:30:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:30:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:30:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:30:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:30:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:30:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:30:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf1u7dv1o/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf1u7dv1o/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf1u7dv1o/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf1u7dv1o/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf1u7dv1o/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf1u7dv1o/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf1u7dv1o/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf1u7dv1o/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:35:31:   L1B product successfully written!
    2025/06/02 16:35:31:   Reading Input Data
    2025/06/02 16:35:31:   Reading metadata for VNIR detector...
    2025/06/02 16:35:31:   Calculating solar irradiance...
    2025/06/02 16:35:31:   Reading metadata for SWIR detector...
    2025/06/02 16:35:31:   Calculating solar irradiance...
    2025/06/02 16:35:31:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:31:   Reading Input Data
    2025/06/02 16:35:31:   Reading metadata for VNIR detector...
    2025/06/02 16:35:32:   Calculating solar irradiance...
    2025/06/02 16:35:32:   Reading metadata for SWIR detector...
    2025/06/02 16:35:32:   Calculating solar irradiance...
    2025/06/02 16:35:32:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:32:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:32:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:32:   Reading metadata for VNIR detector...
    2025/06/02 16:35:32:   Calculating solar irradiance...
    2025/06/02 16:35:32:   Reading metadata for SWIR detector...
    2025/06/02 16:35:33:   Calculating solar irradiance...
    2025/06/02 16:35:33:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:33:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:33:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:33:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:33:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:33:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:33:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 16:35:33:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:35:35:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:35:35:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2bg3x_vx/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2bg3x_vx/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2bg3x_vx/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2bg3x_vx/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2bg3x_vx/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2bg3x_vx/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2bg3x_vx/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2bg3x_vx/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:35:35:   L1B product successfully written!
    2025/06/02 16:35:35:   Reading Input Data
    2025/06/02 16:35:35:   Reading metadata for VNIR detector...
    2025/06/02 16:35:36:   Calculating solar irradiance...
    2025/06/02 16:35:36:   Reading metadata for SWIR detector...
    2025/06/02 16:35:36:   Calculating solar irradiance...
    2025/06/02 16:35:36:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:36:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:35:38:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:35:39:   Reading Input Data
    2025/06/02 16:35:39:   Reading metadata for VNIR detector...
    2025/06/02 16:35:39:   Calculating solar irradiance...
    2025/06/02 16:35:39:   Reading metadata for SWIR detector...
    2025/06/02 16:35:40:   Calculating solar irradiance...
    2025/06/02 16:35:40:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:40:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:40:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:40:   Reading metadata for VNIR detector...
    2025/06/02 16:35:40:   Calculating solar irradiance...
    2025/06/02 16:35:40:   Reading metadata for SWIR detector...
    2025/06/02 16:35:41:   Calculating solar irradiance...
    2025/06/02 16:35:41:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:41:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:41:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:41:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:35:41:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:35:41:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcrjy4rcu/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcrjy4rcu/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcrjy4rcu/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcrjy4rcu/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcrjy4rcu/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcrjy4rcu/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcrjy4rcu/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcrjy4rcu/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 16:35:41:   L1B product successfully written!
    2025/06/02 16:35:41:   Reading Input Data
    2025/06/02 16:35:41:   Reading metadata for VNIR detector...
    2025/06/02 16:35:41:   Calculating solar irradiance...
    2025/06/02 16:35:41:   Reading metadata for SWIR detector...
    2025/06/02 16:35:42:   Calculating solar irradiance...
    2025/06/02 16:35:42:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:42:   Reading Input Data
    2025/06/02 16:35:42:   Reading metadata for VNIR detector...
    2025/06/02 16:35:42:   Calculating solar irradiance...
    2025/06/02 16:35:42:   Reading metadata for SWIR detector...
    2025/06/02 16:35:42:   Calculating solar irradiance...
    2025/06/02 16:35:42:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:42:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:42:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:43:   Reading metadata for VNIR detector...
    2025/06/02 16:35:43:   Calculating solar irradiance...
    2025/06/02 16:35:43:   Reading metadata for SWIR detector...
    2025/06/02 16:35:43:   Calculating solar irradiance...
    2025/06/02 16:35:43:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:43:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:43:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:43:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:35:43:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 16:35:44:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:35:44:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:35:44:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb7ynwqp6/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb7ynwqp6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb7ynwqp6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb7ynwqp6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb7ynwqp6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb7ynwqp6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb7ynwqp6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb7ynwqp6/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 16:35:45:   L1B product successfully written!
    2025/06/02 16:35:45:   Reading Input Data
    2025/06/02 16:35:45:   Reading metadata for VNIR detector...
    2025/06/02 16:35:45:   Calculating solar irradiance...
    2025/06/02 16:35:45:   Reading metadata for SWIR detector...
    2025/06/02 16:35:45:   Calculating solar irradiance...
    2025/06/02 16:35:45:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:45:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:35:46:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 16:35:30:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 16:35:30:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 16:35:30:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 16:35:30:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 16:35:30:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 16:35:30:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:35:30:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:35:30:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:35:30:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:35:30:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:35:33:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 16:35:33:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 16:35:33:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 16:35:33:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 16:35:33:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 16:35:35:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:35:35:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:35:35:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:35:35:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:35:35:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:35:41:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:35:41:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:35:41:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:35:41:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:35:41:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:35:41:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:35:41:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 16:35:43:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:35:43:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 16:35:44:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:35:44:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:35:44:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:35:44:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:35:44:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_read_and_save_single_image_no_snr 0:00:02.480702

Test to read test image 1, save it and read the saved result again - without SNR.

Started | 2025-06-02 16:35:46
Ended | 2025-06-02 16:35:49
Duration | 0:00:02.480702
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:35:47:   Reading Input Data
    2025/06/02 16:35:47:   Reading metadata for VNIR detector...
    2025/06/02 16:35:47:   Calculating solar irradiance...
    2025/06/02 16:35:47:   Reading metadata for SWIR detector...
    2025/06/02 16:35:48:   Calculating solar irradiance...
    2025/06/02 16:35:48:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:48:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:48:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:48:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf38apbzx/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf38apbzx/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf38apbzx/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf38apbzx/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf38apbzx/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf38apbzx/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf38apbzx/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpf38apbzx/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:35:48:   L1B product successfully written!
    2025/06/02 16:35:48:   Reading Input Data
    2025/06/02 16:35:48:   Reading metadata for VNIR detector...
    2025/06/02 16:35:48:   Calculating solar irradiance...
    2025/06/02 16:35:48:   Reading metadata for SWIR detector...
    2025/06/02 16:35:49:   Calculating solar irradiance...
    2025/06/02 16:35:49:   Reading image masks in VNIR sensor geometry.

##### Captured stderr call

    2025/06/02 16:35:48:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:35:48:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:35:48:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:35:48:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:35:48:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_read_and_save_single_image_with_snr 0:00:03.247561

Test to read test image 1, save it and read the saved result again - with SNR.

Started | 2025-06-02 16:35:49
Ended | 2025-06-02 16:35:52
Duration | 0:00:03.247561
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:35:49:   Reading Input Data
    2025/06/02 16:35:50:   Reading metadata for VNIR detector...
    2025/06/02 16:35:50:   Calculating solar irradiance...
    2025/06/02 16:35:50:   Reading metadata for SWIR detector...
    2025/06/02 16:35:50:   Calculating solar irradiance...
    2025/06/02 16:35:50:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:50:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:50:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:50:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:35:51:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:35:51:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy6lvi7s5/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy6lvi7s5/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy6lvi7s5/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy6lvi7s5/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy6lvi7s5/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy6lvi7s5/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy6lvi7s5/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy6lvi7s5/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 16:35:51:   L1B product successfully written!
    2025/06/02 16:35:51:   Reading Input Data
    2025/06/02 16:35:51:   Reading metadata for VNIR detector...
    2025/06/02 16:35:52:   Calculating solar irradiance...
    2025/06/02 16:35:52:   Reading metadata for SWIR detector...
    2025/06/02 16:35:52:   Calculating solar irradiance...
    2025/06/02 16:35:52:   Reading image masks in VNIR sensor geometry.

##### Captured stderr call

    2025/06/02 16:35:51:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 16:35:51:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 16:35:51:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 16:35:51:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 16:35:51:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader_DLR::test_read_inputdata 0:00:02.366131

Started | 2025-06-02 16:35:52
Ended | 2025-06-02 16:35:54
Duration | 0:00:02.366131
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:35:52:   Reading Input Data
    2025/06/02 16:35:52:   Reading metadata for VNIR detector...
    2025/06/02 16:35:53:   Calculating solar irradiance...
    2025/06/02 16:35:53:   Reading metadata for SWIR detector...
    2025/06/02 16:35:53:   Calculating solar irradiance...
    2025/06/02 16:35:53:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:53:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:54:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:54:   Computing VNIR geolayer...
    2025/06/02 16:35:54:   Computing SWIR geolayer...
    2025/06/02 16:35:54:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE_VNIR.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_PIXELMASK_VNIR.TIF.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.png.
    Writing GeoArray of size (100, 1000, 124) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE_SWIR.TIF.
    Writing GeoArray of size (100, 1000, 124) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_PIXELMASK_SWIR.TIF.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.png.
    2025/06/02 16:35:54:   L1B product successfully written!

##### Captured stderr call

    2025/06/02 16:35:52:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader_DLR::test_read_inputdata_dont_drop_bad_bands 0:00:01.801841

Started | 2025-06-02 16:35:54
Ended | 2025-06-02 16:35:56
Duration | 0:00:01.801841
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:35:55:   Reading Input Data
    2025/06/02 16:35:55:   Reading metadata for VNIR detector...
    2025/06/02 16:35:55:   Calculating solar irradiance...
    2025/06/02 16:35:55:   Reading metadata for SWIR detector...
    2025/06/02 16:35:55:   Calculating solar irradiance...
    2025/06/02 16:35:55:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:55:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:56:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:56:   Computing VNIR geolayer...
    2025/06/02 16:35:56:   Computing SWIR geolayer...

##### Captured stderr call

    2025/06/02 16:35:55:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_orthorectification.py 10 0:00:24.453786

### PASSED Test_Orthorectifier::test_run_transformation_ll 0:00:05.494542

Started | 2025-06-02 16:35:56
Ended | 2025-06-02 16:36:02
Duration | 0:00:05.494542
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:35:57:   Reading Input Data
    2025/06/02 16:35:57:   Reading metadata for VNIR detector...
    2025/06/02 16:35:57:   Calculating solar irradiance...
    2025/06/02 16:35:57:   Reading metadata for SWIR detector...
    2025/06/02 16:35:57:   Calculating solar irradiance...
    2025/06/02 16:35:57:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:35:57:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:35:57:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:35:57:   Starting orthorectification...
    2025/06/02 16:35:57:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 4326): (10.691214991975885, 47.455058810417405, 11.070768, 47.540321)
    2025/06/02 16:35:57:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:35:58:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:36:00:   Merging VNIR and SWIR data...
    2025/06/02 16:36:00:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 16:36:00:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 16:36:01:   Generating L2A metadata...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier::test_run_transformation_utm 0:00:05.209116

Started | 2025-06-02 16:36:02
Ended | 2025-06-02 16:36:07
Duration | 0:00:05.209116
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:36:02:   Reading Input Data
    2025/06/02 16:36:02:   Reading metadata for VNIR detector...
    2025/06/02 16:36:02:   Calculating solar irradiance...
    2025/06/02 16:36:02:   Reading metadata for SWIR detector...
    2025/06/02 16:36:03:   Calculating solar irradiance...
    2025/06/02 16:36:03:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:36:03:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:36:03:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:36:03:   Starting orthorectification...
    2025/06/02 16:36:03:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32632): (627300.0, 5257770.0, 656040.0, 5266620.0)
    2025/06/02 16:36:03:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:36:04:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:36:05:   Merging VNIR and SWIR data...
    2025/06/02 16:36:05:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 16:36:05:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 16:36:06:   Generating L2A metadata...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier_DLR::test_run_transformation_ll 0:00:06.774614

Started | 2025-06-02 16:36:07
Ended | 2025-06-02 16:36:14
Duration | 0:00:06.774614
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:36:07:   Reading Input Data
    2025/06/02 16:36:07:   Reading metadata for VNIR detector...
    2025/06/02 16:36:07:   Calculating solar irradiance...
    2025/06/02 16:36:08:   Reading metadata for SWIR detector...
    2025/06/02 16:36:08:   Calculating solar irradiance...
    2025/06/02 16:36:08:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:36:08:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:36:08:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:36:08:   Computing VNIR geolayer...
    2025/06/02 16:36:09:   Computing SWIR geolayer...
    2025/06/02 16:36:09:   Starting orthorectification...
    2025/06/02 16:36:09:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 4326): (-1.2717290915354968, 44.60009471477741, -0.9054060033197534, 44.68406888113938)
    2025/06/02 16:36:09:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:36:10:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:36:11:   Merging VNIR and SWIR data...
    2025/06/02 16:36:11:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 16:36:11:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 16:36:11:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 16:36:12:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 16:36:12:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 16:36:12:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 16:36:12:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 16:36:13:   Generating L2A metadata...

##### Captured stderr call

    2025/06/02 16:36:07:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier_DLR::test_run_transformation_utm 0:00:06.959174

Started | 2025-06-02 16:36:14
Ended | 2025-06-02 16:36:21
Duration | 0:00:06.959174
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:36:14:   Reading Input Data
    2025/06/02 16:36:14:   Reading metadata for VNIR detector...
    2025/06/02 16:36:14:   Calculating solar irradiance...
    2025/06/02 16:36:14:   Reading metadata for SWIR detector...
    2025/06/02 16:36:15:   Calculating solar irradiance...
    2025/06/02 16:36:15:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:36:15:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:36:15:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:36:15:   Computing VNIR geolayer...
    2025/06/02 16:36:15:   Computing SWIR geolayer...
    2025/06/02 16:36:16:   Starting orthorectification...
    2025/06/02 16:36:16:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636990.0, 4940640.0, 666180.0, 4949340.0)
    2025/06/02 16:36:16:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:36:17:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 16:36:18:   Merging VNIR and SWIR data...
    2025/06/02 16:36:18:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 16:36:18:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 16:36:18:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 16:36:19:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 16:36:19:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 16:36:19:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 16:36:19:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 16:36:20:   Generating L2A metadata...

##### Captured stderr call

    2025/06/02 16:36:14:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_compute_stack 0:00:00.003381

Started | 2025-06-02 16:36:21
Ended | 2025-06-02 16:36:21
Duration | 0:00:00.003381
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_average 0:00:00.003051

Started | 2025-06-02 16:36:21
Ended | 2025-06-02 16:36:21
Duration | 0:00:00.003051
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_order_by_wvl 0:00:00.002275

Started | 2025-06-02 16:36:21
Ended | 2025-06-02 16:36:21
Duration | 0:00:00.002275
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_swir_only 0:00:00.001990

Started | 2025-06-02 16:36:21
Ended | 2025-06-02 16:36:21
Duration | 0:00:00.001990
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_vnir_only 0:00:00.001967

Started | 2025-06-02 16:36:21
Ended | 2025-06-02 16:36:21
Duration | 0:00:00.001967
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_validate_input 0:00:00.003676

Started | 2025-06-02 16:36:21
Ended | 2025-06-02 16:36:21
Duration | 0:00:00.003676
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_radiometric_transform.py 1 0:00:04.306632

### PASSED Test_Radiometric_Transformer::test_transform_TOARad2TOARef 0:00:04.306632

Started | 2025-06-02 16:36:21
Ended | 2025-06-02 16:36:25
Duration | 0:00:04.306632
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Tmp dir: /tmp/tmptszgsid7
    2025/06/02 16:36:21:   Reading Input Data
    2025/06/02 16:36:21:   Reading metadata for VNIR detector...
    2025/06/02 16:36:21:   Calculating solar irradiance...
    2025/06/02 16:36:21:   Reading metadata for SWIR detector...
    2025/06/02 16:36:22:   Calculating solar irradiance...
    2025/06/02 16:36:22:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:36:22:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:36:22:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:36:22:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:36:22:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:36:23:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/06/02 16:36:23:   Converting TOA radiance to TOA reflectance for SWIR detector...
    Tmp dir: /tmp/tmplypm709f
    2025/06/02 16:36:23:   Reading Input Data
    2025/06/02 16:36:23:   Reading metadata for VNIR detector...
    2025/06/02 16:36:23:   Calculating solar irradiance...
    2025/06/02 16:36:23:   Reading metadata for SWIR detector...
    2025/06/02 16:36:24:   Calculating solar irradiance...
    2025/06/02 16:36:24:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:36:24:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:36:24:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:36:24:   Computing SNR from VNIR TOA radiance.
    2025/06/02 16:36:25:   Computing SNR from SWIR TOA radiance.
    2025/06/02 16:36:25:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/06/02 16:36:25:   Converting TOA radiance to TOA reflectance for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_spatial_optimization.py 1 0:00:16.803619

### PASSED Test_Spatial_Optimizer::test_optimize_geolayer 0:00:16.803619

Started | 2025-06-02 16:36:25
Ended | 2025-06-02 16:36:42
Duration | 0:00:16.803619
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:36:25:   Reading Input Data
    2025/06/02 16:36:25:   Reading metadata for VNIR detector...
    2025/06/02 16:36:26:   Calculating solar irradiance...
    2025/06/02 16:36:26:   Reading metadata for SWIR detector...
    2025/06/02 16:36:26:   Calculating solar irradiance...
    2025/06/02 16:36:26:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:36:26:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:36:26:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:36:27:   Computing VNIR geolayer...
    2025/06/02 16:36:27:   Computing SWIR geolayer...
    2025/06/02 16:36:27:   Temporarily transforming EnMAP band 40 to map geometry for co-registration.
    2025/06/02 16:36:27:   Temporarily transforming EnMAP water mask to map geometry for co-registration.
    2025/06/02 16:36:27:   Preparing reference image for co-registration.
    2025/06/02 16:36:28:   Computing tie points between the EnMAP image and the given spatial reference image.
    Calculating footprint polygon and actual data corner coordinates for reference image...
    Bounding box of calculated footprint for reference image:
    	(637005.0, 4940640.0, 666300.0, 4949895.0)
    Bounding box of calculated footprint for image to be shifted:
    	(637009.9236523756, 4940648.633479693, 666298.6703669054, 4949893.375184522)
    Matching window position (X,Y): 651655.4222751356/4945271.096554121
    Target window size (256, 256) not possible due to too small overlap area or window position too close to an image edge. New matching window size: (164, 164).
    Initializing tie points grid...
    With respect to the provided bad data mask(s) 81 points of initially 242 have been excluded.
    Calculating tie point grid (161 points) using 24 CPU cores...
    Found 131 matches.
    Performing validity checks...
    41 tie points flagged by level 1 filtering (reliability).
    63 tie points flagged by level 2 filtering (SSIM).
    4 tie points flagged by level 3 filtering (RANSAC)
    47 valid tie points remain after filtering.
    2025/06/02 16:36:40:   Generating misregistration array.
    interpolation runtime: 0.33s
    interpolation runtime: 0.30s
    2025/06/02 16:36:41:   Transforming spatial optimization results back to sensor geometry.
    2025/06/02 16:36:41:   Applying results of spatial optimization to geolayer.

##### Captured stderr call

    2025/06/02 16:36:25:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/06/02 16:36:27:   Statically using band 40 for co-registration.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.1% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.3% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.2% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.2% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.5% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.3% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.1% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.1% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.2% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.5% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.5% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.6% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.1% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.2% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.3% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.3% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.1% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.7% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.2% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.2% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.1% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.4% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.1% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 27.1% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 28.0% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 29.2% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 30.3% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 31.3% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 32.1% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 33.1% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 34.0% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 35.2% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 36.3% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 37.4% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 38.4% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 39.5% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 40.0% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 41.5% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 42.3% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 43.4% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 44.6% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 45.4% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 47.2% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 48.1% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 49.4% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 50.6% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 51.2% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 52.0% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 53.5% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 54.3% Complete  => 0:00:00
    Warping progress     |============================----------------------| 55.1% Complete  => 0:00:00
    Warping progress     |============================----------------------| 56.2% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.1% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 58.0% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 59.6% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 60.6% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 61.4% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.2% Complete  => 0:00:00
    Warping progress     |================================------------------| 64.3% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 65.5% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.4% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.1% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.7% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.0% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.6% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.9% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.4% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.1% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.4% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.5% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.1% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.3% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.3% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.4% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.1% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.3% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.3% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.2% Complete  => 0:00:00
    Warping progress     |============================================------| 87.0% Complete  => 0:00:00
    Warping progress     |============================================------| 88.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.6% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.4% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.2% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.2% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.1% Complete  => 0:00:00
    Warping progress     |================================================--| 96.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.1% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:10
    	progress: |=-------------------------------------------------| 1.9% Complete  => 0:00:10
    	progress: |=-------------------------------------------------| 2.5% Complete  => 0:00:10
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 3.7% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 4.3% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 5.0% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 5.6% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 6.2% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 6.8% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 7.5% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 8.1% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 8.7% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 9.3% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 9.9% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 10.6% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 11.2% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 11.8% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 12.4% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 13.0% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 13.7% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 14.3% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 14.9% Complete  => 0:00:11
    	progress: |========------------------------------------------| 15.5% Complete  => 0:00:11
    	progress: |========------------------------------------------| 16.1% Complete  => 0:00:11
    	progress: |========------------------------------------------| 16.8% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 17.4% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 18.0% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 18.6% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 19.3% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 19.9% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 22.4% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 23.0% Complete  => 0:00:11
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:11
    	progress: |============--------------------------------------| 24.2% Complete  => 0:00:11
    	progress: |============--------------------------------------| 24.8% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 25.5% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 26.1% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:11
    	progress: |==============------------------------------------| 27.3% Complete  => 0:00:11
    	progress: |==============------------------------------------| 28.0% Complete  => 0:00:11
    	progress: |==============------------------------------------| 28.6% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 29.2% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 29.8% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 30.4% Complete  => 0:00:11
    	progress: |================----------------------------------| 31.1% Complete  => 0:00:11
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:11
    	progress: |================----------------------------------| 32.3% Complete  => 0:00:11
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:11
    	progress: |=================---------------------------------| 33.5% Complete  => 0:00:11
    	progress: |=================---------------------------------| 34.2% Complete  => 0:00:11
    	progress: |=================---------------------------------| 34.8% Complete  => 0:00:11
    	progress: |==================--------------------------------| 35.4% Complete  => 0:00:11
    	progress: |==================--------------------------------| 36.0% Complete  => 0:00:11
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:11
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:11
    	progress: |===================-------------------------------| 37.9% Complete  => 0:00:11
    	progress: |===================-------------------------------| 38.5% Complete  => 0:00:11
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:11
    	progress: |====================------------------------------| 39.8% Complete  => 0:00:11
    	progress: |====================------------------------------| 40.4% Complete  => 0:00:11
    	progress: |====================------------------------------| 41.0% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 41.6% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 42.9% Complete  => 0:00:11
    	progress: |======================----------------------------| 43.5% Complete  => 0:00:11
    	progress: |======================----------------------------| 44.1% Complete  => 0:00:11
    	progress: |======================----------------------------| 44.7% Complete  => 0:00:11
    	progress: |=======================---------------------------| 45.3% Complete  => 0:00:11
    	progress: |=======================---------------------------| 46.0% Complete  => 0:00:11
    	progress: |=======================---------------------------| 46.6% Complete  => 0:00:11
    	progress: |========================--------------------------| 47.2% Complete  => 0:00:11
    	progress: |========================--------------------------| 47.8% Complete  => 0:00:11
    	progress: |========================--------------------------| 48.4% Complete  => 0:00:11
    	progress: |=========================-------------------------| 49.1% Complete  => 0:00:11
    	progress: |=========================-------------------------| 49.7% Complete  => 0:00:11
    	progress: |=========================-------------------------| 50.3% Complete  => 0:00:11
    	progress: |=========================-------------------------| 50.9% Complete  => 0:00:11
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:11
    	progress: |==========================------------------------| 52.2% Complete  => 0:00:11
    	progress: |==========================------------------------| 52.8% Complete  => 0:00:11
    	progress: |===========================-----------------------| 53.4% Complete  => 0:00:11
    	progress: |===========================-----------------------| 54.0% Complete  => 0:00:11
    	progress: |===========================-----------------------| 54.7% Complete  => 0:00:11
    	progress: |============================----------------------| 55.3% Complete  => 0:00:11
    	progress: |============================----------------------| 55.9% Complete  => 0:00:11
    	progress: |============================----------------------| 56.5% Complete  => 0:00:11
    	progress: |=============================---------------------| 57.1% Complete  => 0:00:11
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:11
    	progress: |=============================---------------------| 58.4% Complete  => 0:00:11
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:11
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:11
    	progress: |==============================--------------------| 60.2% Complete  => 0:00:11
    	progress: |==============================--------------------| 60.9% Complete  => 0:00:11
    	progress: |===============================-------------------| 61.5% Complete  => 0:00:11
    	progress: |===============================-------------------| 62.1% Complete  => 0:00:11
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:11
    	progress: |================================------------------| 63.4% Complete  => 0:00:11
    	progress: |================================------------------| 64.0% Complete  => 0:00:11
    	progress: |================================------------------| 64.6% Complete  => 0:00:11
    	progress: |=================================-----------------| 65.2% Complete  => 0:00:11
    	progress: |=================================-----------------| 65.8% Complete  => 0:00:11
    	progress: |=================================-----------------| 66.5% Complete  => 0:00:11
    	progress: |==================================----------------| 67.1% Complete  => 0:00:11
    	progress: |==================================----------------| 67.7% Complete  => 0:00:12
    	progress: |==================================----------------| 68.3% Complete  => 0:00:12
    	progress: |==================================----------------| 68.9% Complete  => 0:00:12
    	progress: |===================================---------------| 69.6% Complete  => 0:00:12
    	progress: |===================================---------------| 70.2% Complete  => 0:00:12
    	progress: |===================================---------------| 70.8% Complete  => 0:00:12
    	progress: |====================================--------------| 71.4% Complete  => 0:00:12
    	progress: |====================================--------------| 72.0% Complete  => 0:00:12
    	progress: |====================================--------------| 72.7% Complete  => 0:00:12
    	progress: |=====================================-------------| 73.3% Complete  => 0:00:12
    	progress: |=====================================-------------| 73.9% Complete  => 0:00:12
    	progress: |=====================================-------------| 74.5% Complete  => 0:00:12
    	progress: |======================================------------| 75.2% Complete  => 0:00:12
    	progress: |======================================------------| 75.8% Complete  => 0:00:12
    	progress: |======================================------------| 76.4% Complete  => 0:00:12
    	progress: |=======================================-----------| 77.0% Complete  => 0:00:12
    	progress: |=======================================-----------| 77.6% Complete  => 0:00:12
    	progress: |=======================================-----------| 78.3% Complete  => 0:00:12
    	progress: |=======================================-----------| 78.9% Complete  => 0:00:12
    	progress: |========================================----------| 79.5% Complete  => 0:00:12
    	progress: |========================================----------| 80.1% Complete  => 0:00:12
    	progress: |========================================----------| 80.7% Complete  => 0:00:12
    	progress: |=========================================---------| 81.4% Complete  => 0:00:12
    	progress: |=========================================---------| 82.0% Complete  => 0:00:12
    	progress: |=========================================---------| 82.6% Complete  => 0:00:12
    	progress: |==========================================--------| 83.2% Complete  => 0:00:12
    	progress: |==========================================--------| 83.9% Complete  => 0:00:12
    	progress: |==========================================--------| 84.5% Complete  => 0:00:12
    	progress: |===========================================-------| 85.1% Complete  => 0:00:12
    	progress: |===========================================-------| 85.7% Complete  => 0:00:12
    	progress: |===========================================-------| 86.3% Complete  => 0:00:12
    	progress: |===========================================-------| 87.0% Complete  => 0:00:12
    	progress: |============================================------| 87.6% Complete  => 0:00:12
    	progress: |============================================------| 88.2% Complete  => 0:00:12
    	progress: |============================================------| 88.8% Complete  => 0:00:12
    	progress: |=============================================-----| 89.4% Complete  => 0:00:12
    	progress: |=============================================-----| 90.1% Complete  => 0:00:12
    	progress: |=============================================-----| 90.7% Complete  => 0:00:12
    	progress: |==============================================----| 91.3% Complete  => 0:00:12
    	progress: |==============================================----| 91.9% Complete  => 0:00:12
    	progress: |==============================================----| 92.5% Complete  => 0:00:12
    	progress: |===============================================---| 93.2% Complete  => 0:00:12
    	progress: |===============================================---| 93.8% Complete  => 0:00:12
    	progress: |===============================================---| 94.4% Complete  => 0:00:12
    	progress: |================================================--| 95.0% Complete  => 0:00:12
    	progress: |================================================--| 95.7% Complete  => 0:00:12
    	progress: |================================================--| 96.3% Complete  => 0:00:12
    	progress: |================================================--| 96.9% Complete  => 0:00:12
    	progress: |=================================================-| 97.5% Complete  => 0:00:12
    	progress: |=================================================-| 98.1% Complete  => 0:00:12
    	progress: |=================================================-| 98.8% Complete  => 0:00:12
    	progress: |==================================================| 99.4% Complete  => 0:00:12
    	progress: |==================================================| 100.0% Complete  => 0:00:12

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_spatial_transform.py 17 0:00:34.561407

### PASSED Test_Geometry_Transformer::test_to_map_geometry 0:00:02.411622

Started | 2025-06-02 16:36:42
Ended | 2025-06-02 16:36:44
Duration | 0:00:02.411622
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:36:42:   Reading Input Data
    2025/06/02 16:36:42:   Reading metadata for VNIR detector...
    2025/06/02 16:36:43:   Calculating solar irradiance...
    2025/06/02 16:36:43:   Reading metadata for SWIR detector...
    2025/06/02 16:36:43:   Calculating solar irradiance...
    2025/06/02 16:36:43:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:36:43:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:36:43:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Geometry_Transformer::test_to_sensor_geometry 0:00:01.260511

Started | 2025-06-02 16:36:44
Ended | 2025-06-02 16:36:45
Duration | 0:00:01.260511
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 16:36:45:   Reading Input Data
    2025/06/02 16:36:45:   Reading metadata for VNIR detector...
    2025/06/02 16:36:45:   Calculating solar irradiance...
    2025/06/02 16:36:45:   Reading metadata for SWIR detector...
    2025/06/02 16:36:45:   Calculating solar irradiance...
    2025/06/02 16:36:45:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:36:45:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:36:45:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2D 0:00:02.363379

Started | 2025-06-02 16:36:45
Ended | 2025-06-02 16:36:48
Duration | 0:00:02.363379
Markers |
Fixtures | request

#### Setup

##### Captured stdout setup

    2025/06/02 16:36:46:   Reading Input Data
    2025/06/02 16:36:46:   Reading metadata for VNIR detector...
    2025/06/02 16:36:46:   Calculating solar irradiance...
    2025/06/02 16:36:46:   Reading metadata for SWIR detector...
    2025/06/02 16:36:46:   Calculating solar irradiance...
    2025/06/02 16:36:46:   Reading image masks in VNIR sensor geometry.
    2025/06/02 16:36:47:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 16:36:47:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 16:36:47:   Computing VNIR geolayer...
    2025/06/02 16:36:47:   Computing SWIR geolayer...

##### Captured stderr setup

    2025/06/02 16:36:46:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log setup

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2band3DInput_2DGeolayer 0:00:00.448103

Started | 2025-06-02 16:36:48
Ended | 2025-06-02 16:36:48
Duration | 0:00:00.448103
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2band3DInput_3DGeolayer 0:00:00.447967

Started | 2025-06-02 16:36:48
Ended | 2025-06-02 16:36:49
Duration | 0:00:00.447967
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_VNIR_to_SWIR_2D 0:00:00.425756

Started | 2025-06-02 16:36:49
Ended | 2025-06-02 16:36:49
Duration | 0:00:00.425756
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_VNIR_to_SWIR_3D 0:00:19.834128

Started | 2025-06-02 16:36:49
Ended | 2025-06-02 16:37:09
Duration | 0:00:19.834128
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_geolayer 0:00:00.460520

Started | 2025-06-02 16:37:09
Ended | 2025-06-02 16:37:09
Duration | 0:00:00.460520
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_geolayer_average_elevation 0:00:00.415782

Started | 2025-06-02 16:37:09
Ended | 2025-06-02 16:37:10
Duration | 0:00:00.415782
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_normalized_image_coordinates 0:00:00.003846

Started | 2025-06-02 16:37:10
Ended | 2025-06-02 16:37:10
Duration | 0:00:00.003846
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_normalize_coordinates 0:00:00.002734

Started | 2025-06-02 16:37:10
Ended | 2025-06-02 16:37:10
Duration | 0:00:00.002734
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_transform_LonLatHeight_to_RowCol 0:00:00.003033

Started | 2025-06-02 16:37:10
Ended | 2025-06-02 16:37:10
Duration | 0:00:00.003033
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_average_elevation 0:00:02.005345

Started | 2025-06-02 16:37:10
Ended | 2025-06-02 16:37:12
Duration | 0:00:02.005345
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_faulty_coeff_set 0:00:00.510233

Test in case of a faulty/inaccurate coeff set the result really does not contain NaNs.

NOTE: NaNs should be filled automatically.

Started | 2025-06-02 16:37:12
Ended | 2025-06-02 16:37:12
Duration | 0:00:00.510233
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_multiple_coeff_sets_multiprocessing 0:00:02.030797

Started | 2025-06-02 16:37:12
Ended | 2025-06-02 16:37:14
Duration | 0:00:02.030797
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_multiple_coeff_sets_singleprocessing 0:00:01.476098

Started | 2025-06-02 16:37:14
Ended | 2025-06-02 16:37:16
Duration | 0:00:01.476098
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_one_unique_coeff_set 0:00:00.461551

Started | 2025-06-02 16:37:16
Ended | 2025-06-02 16:37:16
Duration | 0:00:00.461551
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_srf.py 1 0:00:00.005404

### PASSED Test_SRF::test_from_cwl_fwhm 0:00:00.005404

Started | 2025-06-02 16:37:16
Ended | 2025-06-02 16:37:16
Duration | 0:00:00.005404
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown